-------------------------------------------------------------------------------
--
-- Simple VGA raster display
--
-- Stephen A. Edwards
-- sedwards@cs.columbia.edu
--
-------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_arith.all;

entity de2_vga_raster is
  
  port (
    reset_n : in std_logic;
    clk50   : in std_logic;    	 -- Should be 25.125 MHz
	 sram_read  : in std_logic_vector(15 downto 0);
    sram_add  : out std_logic_vector (17 downto 0);
    read       : in  std_logic;
    write      : in  std_logic;
    chipselect : in  std_logic;
    address    : in  std_logic_vector(4 downto 0);
    readdata   : out std_logic_vector(15 downto 0);
    writedata  : in  std_logic_vector(15 downto 0);
    VGA_CLK,                         -- Clock
    VGA_HS,                          -- H_SYNC
    VGA_VS,                          -- V_SYNC
    VGA_BLANK,                       -- BLANK
    VGA_SYNC : out std_logic;        -- SYNC
    VGA_R,                           -- Red[9:0]
    VGA_G,                           -- Green[9:0]
    VGA_B : out std_logic_vector(9 downto 0) -- Blue[9:0]
    );

end de2_vga_raster;

architecture rtl of de2_vga_raster is

component V_control
	port(
			clk		:	in std_logic;
			Vcount	:	in unsigned(9 downto 0);
			Pattern_V	:	in	integer;
			locate	:	in	integer;
			Vcounter	:	out integer;
			flag_v	:	out	std_logic;
			reset_n	:	in		std_logic;
			EndofLine:	in	std_logic
			);
end component;

component H_control
	port(
			clk		:	in std_logic;
			Hcount	:	in unsigned(9 downto 0);
			Pattern_H	:	in	integer;
			locate	:	in	integer;
			Hcounter	:	out integer;
			flag_h	:	out	std_logic
			);
end component;

  -- Video parameters
  
  constant HTOTAL       : integer := 800;
  constant HSYNC        : integer := 96;
  constant HBACK_PORCH  : integer := 48;
  constant HACTIVE      : integer := 640;
  constant HFRONT_PORCH : integer := 16;
  
  constant VTOTAL       : integer := 525;
  constant VSYNC        : integer := 2;
  constant VBACK_PORCH  : integer := 33;
  constant VACTIVE      : integer := 480;
  constant VFRONT_PORCH : integer := 10;

  constant RECTANGLE_HSTART : integer := 100;
  constant RECTANGLE_HEND   : integer := 540;
  constant RECTANGLE_VSTART : integer := 100;
  constant RECTANGLE_VEND   : integer := 380;
  constant PATTERN_V : integer :=80;
  constant PATTERN_H : integer :=60;
  constant PATTERN_V_C : integer :=60;
  constant PATTERN_H_C : integer :=60;
  constant PATTERN_V_E : integer :=80;
  constant PATTERN_H_E : integer :=60;
  constant PATTERN_V_B : integer :=25;
  constant PATTERN_H_B : integer :=66;

  -- Signals for the video controller
  signal clk : std_logic;
  signal Hcount : unsigned(9 downto 0);  -- Horizontal position (0-800)
  signal Vcount : unsigned(9 downto 0);  -- Vertical position (0-524)
  signal EndOfLine, EndOfField : std_logic;
  signal Hcounter : integer :=0 ;
  signal Vcounter : integer :=0 ;
  signal Hcounter_B : integer :=0 ;
  signal Vcounter_B : integer :=0 ;
  signal Hcounter_C : integer :=0 ;
  signal Vcounter_C : integer :=0 ;
  signal Hcounter_E : integer :=0 ;
  signal Vcounter_E : integer :=0 ;
  signal Hcounter_E1 : integer :=0 ;
  signal Vcounter_E1 : integer :=0 ;
  signal Hcounter_E2 : integer :=0 ;
  signal Vcounter_E2 : integer :=0 ;
  signal Hcounter_E3 : integer :=0 ;
  signal Vcounter_E3 : integer :=0 ;
  signal Hcounter_BOX : integer :=0 ;
  signal Vcounter_BOX : integer :=0 ;
  signal Hcounter_BM : integer :=0 ;
  signal Vcounter_BM : integer :=0 ;
  signal Hcounter_LV1 : integer :=0 ;
  signal Vcounter_LV1 : integer :=0 ;
  signal Hcounter_LV2 : integer :=0 ;
  signal Hcounter_LV3 : integer :=0 ;
  signal Vcounter_BU : integer :=0 ;
  signal Hcounter_BU1 : integer :=0 ;
  signal Hcounter_BU2 : integer :=0 ;
  signal Hcounter_BU3 : integer :=0 ;
  signal Hcounter_BU4 : integer :=0 ;
  signal Hcounter_BU5 : integer :=0 ;
  signal cmpindex1 : integer :=0;
  signal cmpindex2 : integer :=0;
  signal cmpindex3 : integer :=0;
  signal cmpindex4 : integer :=0;
  signal cmpindex5 : integer :=0;
  signal cmpindex6 : integer :=0;
  signal cmpindex8 : integer :=0;
  signal cmpindexLV1 : integer :=0;
  signal cmpindexLV2 : integer :=0;
  signal cmpindexLV3 : integer :=0;
  signal cmpindexBU1 : integer :=0;
  signal cmpindexBU2 : integer :=0;
  signal cmpindexBU3 : integer :=0;
  signal cmpindexBU4 : integer :=0;
  signal cmpindexBU5 : integer :=0;
  signal cmpindexBOX : integer :=0;
  signal LEVEL_3_R : std_logic_vector(9 downto 0);
  signal LEVEL_3_G : std_logic_vector(9 downto 0);
  signal LEVEL_3_B : std_logic_vector(9 downto 0);
  signal LEVEL_2_R : std_logic_vector(9 downto 0);
  signal LEVEL_2_G : std_logic_vector(9 downto 0);
  signal LEVEL_2_B : std_logic_vector(9 downto 0);
  signal LEVEL_1_R : std_logic_vector(9 downto 0);
  signal LEVEL_1_G : std_logic_vector(9 downto 0);
  signal LEVEL_1_B : std_logic_vector(9 downto 0);
  signal LEVEL_0_R : std_logic_vector(9 downto 0);
  signal LEVEL_0_G : std_logic_vector(9 downto 0);
  signal LEVEL_0_B : std_logic_vector(9 downto 0);
  signal level_0 : std_logic :='0';
  signal level_1 : std_logic :='0';
  signal level_2 : std_logic :='0';
  signal level_3 : std_logic :='0';
  signal hcounter_s : integer := 0;
  signal vcounter_s : integer := 0;
  signal mark : std_logic ;


type Array0 is array(0 to 215) of std_logic_vector(23 downto 0);	
type Array1 is array( 0 to 4799) of std_logic_vector(7 downto 0);
type Array2 is array( 0 to PATTERN_V_B*PATTERN_H_B-1) of std_logic_vector(7 downto 0);
type Array3 is array( 0 to PATTERN_V_C*PATTERN_H_C-1) of std_logic_vector(7 downto 0);
type Array4 is array( 0 to PATTERN_V_E*PATTERN_H_E-1) of std_logic_vector(7 downto 0);
type Array5 is array( 0 to 899) of std_logic_vector(7 downto 0);
type Array6 is array( 0 to 2999) of std_logic_vector(7 downto 0);
type Array7 is array(0 to 919) of std_logic_vector(7 downto 0);
type Array8 is array(0 to 2759)of std_logic_vector(7 downto 0);

constant colormap: Array0 :=(
"111111111111111111111111","111111111111111111001110","111111111111111110011001","111111111111111101100110","111111111111111100110011","111111111111111100000000",
"111111111100110011111111","111111111100110011001100","111111111100110010011001","111111111100110001100110","111111111100110000110011","111111111100110000000000",
"111111111001100111111111","111111111001100111001100","111111111001100110011001","111111111001100101100110","111111111001100100110011","111111111001100100000000",
"111111110110011011111111","111111110110011011001100","111111110110011010011001","111111110110011001100110","111111110110011000110011","111111110110011000000000",
"111111110011001111111111","111111110011001111001100","111111110011001110011001","111111110011001101100110","111111110011001100110011","111111110011001100000000",
"111111110000000011111111","111111110000000011001100","111111110000000010011001","111111110000000001100110","111111110000000000110011","111111110000000000000000",
"110011001111111111111111","110011001111111111001100","110011001111111110011001","110011001111111101100110","110011001111111100110011","110011001111111100000000",
"110011001100110011111111","110011001100110011001100","110011001100110010011001","110011001100110001100110","110011001100110000110011","110011001100110000000000",
"110011001001100111111111","110011001001100111001100","110011001001100110011001","110011001001100101100110","110011001001100100110011","110011001001100100000000",
"110011000110011011111111","110011000110011011001100","110011000110011010011001","110011000110011001100110","110011000110011000110011","110011000110011000000000",
"110011000011001111111111","110011000011001111001100","110011000011001110011001","110011000011001101100110","110011000011001100110011","110011000011001100000000",
"110011000000000011111111","110011000000000011001100","110011000000000010011001","110011000000000001100110","110011000000000000110011","110011000000000000000000",
"100110011111111111111111","100110011111111111001100","100110011111111110011001","100110011111111101100110","100110011111111100110011","100110011111111100000000",
"100110011100110011111111","100110011100110011001100","100110011100110010011001","100110011100110001100110","100110011100110000110011","100110011100110000000000",
"100110011001100111111111","100110011001100111001100","100110011001100110011001","100110011001100101100110","100110011001100100110011","100110011001100100000000",
"100110010110011011111111","100110010110011011001100","100110010110011010011001","100110010110011001100110","100110010110011000110011","100110010110011000000000",
"100110010011001111111111","100110010011001111001100","100110010011001110011001","100110010011001101100110","100110010011001100110011","100110010011001100000000",
"100110010000000011111111","100110010000000011001100","100110010000000010011001","100110010000000001100110","100110010000000000110011","100110010000000000000000",
"011001101111111111111111","011001101111111111001100","011001101111111110011001","011001101111111101100110","011001101111111100110011","011001101111111100000000",
"011001101100110011111111","011001101100110011001100","011001101100110010011001","011001101100110001100110","011001101100110000110011","011001101100110000000000",
"011001101001100111111111","011001101001100111001100","011001101001100110011001","011001101001100101100110","011001101001100100110011","011001101001100100000000",
"011001100110011011111111","011001100110011011001100","011001100110011010011001","011001100110011001100110","011001100110011000110011","011001100110011000000000",
"011001100011001111111111","011001100011001111001100","011001100011001110011001","011001100011001101100110","011001100011001100110011","011001100011001100000000",
"011001100000000011111111","011001100000000011001100","011001100000000010011001","011001100000000001100110","011001100000000000110011","011001100000000000000000",
"001100111111111111111111","001100111111111111001100","001100111111111110011001","001100111111111101100110","001100111111111100110011","001100111111111100000000",
"001100111100110011111111","001100111100110011001100","001100111100110010011001","001100111100110001100110","001100111100110000110011","001100111100110000000000",
"001100111001100111111111","001100111001100111001100","001100111001100110011001","001100111001100101100110","001100111001100100110011","001100111001100100000000",
"001100110110011011111111","001100110110011011001100","001100110110011010011001","001100110110011001100110","001100110110011000110011","001100110110011000000000",
"001100110011001111111111","001100110011001111001100","001100110011001110011001","001100110011001101100110","001100110011001100110011","001100110011001100000000",
"001100110000000011111111","001100110000000011001100","001100110000000010011001","001100110000000001100110","001100110000000000110011","001100110000000000000000",
"000000001111111111111111","000000001111111111001100","000000001111111110011001","000000001111111101100110","000000001111111100110011","000000001111111100000000",
"000000001100110011111111","000000001100110011001100","000000001100110010011001","000000001100110001100110","000000001100110000110011","000000001100110000000000",
"000000001001100111111111","000000001001100111001100","000000001001100110011001","000000001001100101100110","000000001001100100110011","000000001001100100000000",
"000000000110011011111111","000000000110011011001100","000000000110011010011001","000000000110011001100110","000000000110011000110011","000000000110011000000000",
"000000000011001111111111","000000000011001111001100","000000000011001110011001","000000000011001101100110","000000000011001100110011","000000000011001100000000",
"000000000000000011111111","000000000000000011001100","000000000000000010011001","000000000000000001100110","000000000000000000110011","000000000000000000000000"
);

constant bomb : Array1 :=(
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"55",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"87",X"87",X"87",X"B1",X"AA",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"2A",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"80",X"87",X"07",X"07",X"0E",X"AB",X"D5",X"06",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"AB",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"4F",X"56",X"7A",X"80",X"0E",X"0E",X"0E",X"08",X"08",X"B2",X"AB",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"80",X"AC",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"80",X"87",X"39",X"87",X"5D",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"D6",X"80",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2A",X"57",X"5F",X"80",X"00",X"00",X"00",X"00",X"80",X"87",X"08",X"08",X"08",X"0E",X"32",X"0E",X"0E",X"0E",X"0E",X"08",X"5D",X"AB",X"00",X"00",X"2B",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2A",X"58",X"35",X"86",X"00",X"00",X"80",X"87",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"32",X"B1",X"2B",X"00",X"55",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"80",X"0A",X"34",X"86",X"80",X"87",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"87",X"2B",X"00",X"56",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2A",X"AB",X"04",X"34",X"D5",X"32",X"08",X"0E",X"0E",X"32",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"80",X"2B",X"2B",X"AB",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"80",X"AA",X"5D",X"04",X"58",X"B1",X"31",X"08",X"0E",X"5D",X"32",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"AB",X"81",X"5D",X"AB",X"87",X"5C",X"00",X"00",X"00",X"2A",X"80",X"80",X"80",X"2A",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"87",X"08",X"87",X"34",X"04",X"5E",X"B1",X"32",X"08",X"5C",X"87",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"08",X"5C",X"87",X"0E",X"0E",X"87",X"0E",X"5D",X"AB",X"55",X"80",X"AB",X"87",X"5D",X"87",X"AB",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"5D",X"08",X"38",X"AB",X"04",X"04",X"82",X"B1",X"0E",X"0E",X"B1",X"87",X"08",X"08",X"0E",X"0E",X"0E",X"0E",X"32",X"0E",X"0E",X"5C",X"AB",X"0E",X"07",X"38",X"D5",X"AB",X"32",X"08",X"08",X"08",X"38",X"AA",X"2A",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"80",X"AB",X"5D",X"08",X"08",X"86",X"82",X"04",X"04",X"82",X"86",X"0E",X"87",X"D6",X"87",X"5C",X"5D",X"0E",X"08",X"08",X"08",X"81",X"81",X"5C",X"AB",X"32",X"08",X"08",X"32",X"0E",X"08",X"0E",X"0E",X"0E",X"08",X"5C",X"4F",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"80",X"63",X"5D",X"5D",X"32",X"0E",X"08",X"32",X"AB",X"2E",X"04",X"04",X"58",X"AA",X"AB",X"87",X"B1",X"2E",X"34",X"86",X"5C",X"5C",X"AA",X"D5",X"AA",X"5D",X"81",X"38",X"08",X"0E",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"80",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"5D",X"08",X"08",X"08",X"0E",X"08",X"0E",X"08",X"5C",X"81",X"04",X"0A",X"04",X"34",X"87",X"2E",X"04",X"57",X"2E",X"2E",X"2E",X"34",X"58",X"5D",X"D5",X"57",X"58",X"5C",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"32",X"86",X"2A",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"55",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"80",X"87",X"08",X"0E",X"0E",X"32",X"56",X"32",X"0E",X"32",X"B1",X"2E",X"04",X"04",X"04",X"04",X"58",X"7C",X"B1",X"87",X"28",X"2E",X"58",X"04",X"04",X"81",X"34",X"2E",X"86",X"31",X"0E",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"08",X"5C",X"55",X"2A",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"55",X"AB",X"AB",X"80",X"55",X"00",X"00",X"00",X"00",X"2B",X"AB",X"32",X"08",X"0E",X"08",X"5C",X"87",X"5D",X"57",X"87",X"AB",X"7B",X"57",X"57",X"57",X"81",X"8E",X"1D",X"6A",X"AC",X"6A",X"8E",X"2E",X"0A",X"81",X"04",X"2E",X"81",X"57",X"5C",X"31",X"08",X"08",X"08",X"07",X"32",X"32",X"0E",X"32",X"5C",X"80",X"2A",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"55",X"86",X"D5",X"AB",X"80",X"55",X"2A",X"00",X"7F",X"87",X"08",X"0E",X"0E",X"07",X"80",X"58",X"04",X"2D",X"8D",X"6A",X"8E",X"8E",X"8E",X"46",X"1D",X"1C",X"1D",X"41",X"1D",X"46",X"81",X"57",X"57",X"04",X"2E",X"5D",X"04",X"2E",X"80",X"5C",X"5C",X"56",X"80",X"5C",X"0E",X"08",X"0E",X"0E",X"39",X"87",X"2A",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2B",X"80",X"D5",X"D6",X"AB",X"56",X"80",X"B1",X"32",X"31",X"07",X"07",X"5C",X"2E",X"04",X"04",X"5D",X"22",X"1D",X"1D",X"1D",X"1C",X"40",X"40",X"1C",X"1C",X"1C",X"1D",X"8D",X"A5",X"04",X"0A",X"0A",X"5D",X"2E",X"04",X"2E",X"2E",X"87",X"D5",X"D5",X"32",X"32",X"5C",X"0E",X"0E",X"08",X"5D",X"80",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"AB",X"AC",X"5E",X"2D",X"57",X"81",X"5C",X"86",X"87",X"2E",X"34",X"2E",X"81",X"6A",X"1D",X"40",X"40",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"40",X"AB",X"51",X"04",X"04",X"57",X"57",X"04",X"04",X"04",X"2E",X"B1",X"AB",X"80",X"80",X"32",X"08",X"0E",X"0E",X"0E",X"87",X"2B",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"80",X"57",X"2E",X"04",X"2E",X"58",X"57",X"5D",X"81",X"81",X"A5",X"64",X"1D",X"1C",X"40",X"40",X"40",X"1C",X"1C",X"40",X"40",X"40",X"1D",X"46",X"D5",X"57",X"04",X"2E",X"57",X"04",X"04",X"0A",X"57",X"AB",X"AA",X"D5",X"32",X"08",X"0E",X"0E",X"0E",X"08",X"81",X"2B",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2A",X"D5",X"87",X"5D",X"04",X"04",X"04",X"04",X"0A",X"04",X"57",X"8E",X"1D",X"1C",X"40",X"40",X"46",X"46",X"1C",X"1C",X"1C",X"1C",X"40",X"1D",X"40",X"B1",X"A5",X"7B",X"81",X"57",X"81",X"87",X"B1",X"2E",X"81",X"AA",X"08",X"0E",X"0E",X"0E",X"0E",X"32",X"80",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"B1",X"32",X"5C",X"81",X"2E",X"04",X"0A",X"0A",X"04",X"57",X"8E",X"1D",X"1C",X"1C",X"22",X"16",X"10",X"0A",X"0A",X"0A",X"10",X"40",X"46",X"1C",X"1D",X"6A",X"8D",X"87",X"8E",X"46",X"6A",X"5D",X"04",X"2E",X"81",X"32",X"0E",X"0E",X"0E",X"08",X"80",X"80",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"AB",X"AB",X"08",X"08",X"31",X"80",X"58",X"04",X"0A",X"04",X"81",X"6A",X"1C",X"1C",X"46",X"16",X"04",X"04",X"0A",X"04",X"04",X"04",X"0A",X"1C",X"46",X"1C",X"1C",X"1D",X"1D",X"1D",X"1D",X"87",X"51",X"04",X"04",X"58",X"5C",X"08",X"0E",X"08",X"5C",X"AB",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"D5",X"5C",X"08",X"0E",X"08",X"07",X"80",X"81",X"04",X"57",X"8D",X"1D",X"1C",X"1C",X"40",X"0A",X"0A",X"3A",X"3A",X"10",X"0A",X"04",X"04",X"04",X"10",X"1C",X"46",X"1C",X"1C",X"1C",X"1C",X"87",X"2E",X"04",X"04",X"5D",X"80",X"08",X"08",X"5C",X"AB",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"D5",X"32",X"08",X"0E",X"08",X"0E",X"32",X"81",X"81",X"87",X"40",X"1C",X"40",X"40",X"1C",X"04",X"10",X"3A",X"10",X"17",X"16",X"10",X"0A",X"04",X"04",X"0A",X"10",X"1C",X"40",X"1C",X"40",X"81",X"0A",X"0A",X"04",X"34",X"87",X"07",X"32",X"AB",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"80",X"87",X"07",X"08",X"0E",X"32",X"87",X"82",X"3A",X"6A",X"1C",X"1C",X"40",X"1C",X"46",X"16",X"04",X"10",X"16",X"10",X"3A",X"3A",X"16",X"3A",X"34",X"0A",X"04",X"04",X"0A",X"1C",X"1C",X"40",X"81",X"04",X"0A",X"0A",X"04",X"5D",X"56",X"5C",X"80",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5C",X"5D",X"08",X"08",X"08",X"32",X"5C",X"AB",X"8D",X"1D",X"1C",X"40",X"1C",X"1C",X"1C",X"0A",X"04",X"10",X"16",X"34",X"3A",X"10",X"10",X"5E",X"3A",X"16",X"0A",X"04",X"04",X"10",X"1C",X"46",X"5D",X"04",X"0A",X"04",X"04",X"87",X"D5",X"AB",X"87",X"31",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"5C",X"08",X"0E",X"0E",X"08",X"08",X"5D",X"A5",X"B1",X"46",X"1D",X"1C",X"46",X"10",X"04",X"04",X"0A",X"3A",X"10",X"10",X"10",X"10",X"10",X"10",X"3A",X"16",X"0A",X"04",X"0A",X"1C",X"1D",X"63",X"2D",X"04",X"0A",X"04",X"81",X"B1",X"81",X"80",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5C",X"0E",X"0E",X"0E",X"0E",X"07",X"5C",X"2E",X"2D",X"D5",X"6A",X"1C",X"46",X"10",X"04",X"04",X"0A",X"3A",X"11",X"5E",X"87",X"10",X"10",X"10",X"10",X"3A",X"10",X"03",X"10",X"1C",X"1D",X"6A",X"57",X"04",X"04",X"0A",X"AB",X"B1",X"08",X"5C",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"80",X"38",X"08",X"08",X"08",X"56",X"5D",X"0A",X"04",X"2D",X"AB",X"40",X"1C",X"16",X"04",X"04",X"0A",X"16",X"10",X"87",X"AA",X"10",X"10",X"10",X"10",X"3A",X"10",X"03",X"10",X"22",X"1C",X"40",X"AB",X"2E",X"04",X"2E",X"AB",X"81",X"0E",X"5C",X"AB",X"80",X"55",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"81",X"0E",X"32",X"5C",X"86",X"D5",X"81",X"04",X"04",X"2E",X"AB",X"8E",X"1D",X"1C",X"10",X"04",X"0A",X"16",X"10",X"3A",X"AB",X"5E",X"11",X"10",X"3A",X"16",X"10",X"03",X"16",X"40",X"1C",X"1C",X"40",X"CF",X"58",X"5D",X"5C",X"08",X"0E",X"32",X"5D",X"81",X"B1",X"AB",X"2A",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5C",X"38",X"08",X"32",X"87",X"D5",X"AB",X"B1",X"5D",X"5D",X"81",X"33",X"AB",X"40",X"1C",X"1C",X"04",X"04",X"16",X"16",X"11",X"5D",X"5E",X"11",X"5D",X"5E",X"17",X"0A",X"03",X"16",X"1C",X"1C",X"1C",X"1C",X"40",X"B2",X"AB",X"08",X"0E",X"0E",X"0E",X"08",X"08",X"0E",X"AB",X"AB",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"80",X"38",X"08",X"0E",X"5D",X"87",X"AB",X"D5",X"B1",X"5D",X"04",X"04",X"81",X"8E",X"1C",X"22",X"10",X"04",X"0A",X"3A",X"16",X"10",X"11",X"3A",X"87",X"3A",X"17",X"0A",X"03",X"16",X"22",X"1C",X"1C",X"1C",X"1D",X"87",X"AA",X"32",X"08",X"08",X"08",X"0E",X"0E",X"08",X"08",X"AB",X"55",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"81",X"08",X"08",X"0E",X"86",X"D5",X"81",X"0A",X"04",X"0A",X"04",X"57",X"8D",X"1C",X"1C",X"1C",X"0A",X"03",X"10",X"3A",X"10",X"10",X"3A",X"3A",X"3A",X"3A",X"10",X"03",X"0A",X"1C",X"1C",X"1C",X"1D",X"64",X"AB",X"AB",X"AA",X"80",X"80",X"80",X"38",X"0E",X"0E",X"08",X"5C",X"AA",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"AB",X"86",X"AA",X"81",X"2E",X"04",X"04",X"0A",X"0A",X"04",X"2D",X"87",X"1C",X"1C",X"1C",X"10",X"04",X"0A",X"10",X"16",X"10",X"10",X"11",X"3A",X"3A",X"10",X"09",X"04",X"16",X"1C",X"1C",X"1C",X"B0",X"2D",X"33",X"D4",X"B1",X"87",X"32",X"32",X"0E",X"0E",X"0E",X"32",X"80",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2A",X"55",X"80",X"81",X"5E",X"2E",X"04",X"04",X"04",X"04",X"04",X"04",X"04",X"2E",X"87",X"40",X"1C",X"1C",X"10",X"04",X"0A",X"10",X"3A",X"10",X"10",X"34",X"10",X"10",X"3A",X"10",X"03",X"10",X"22",X"1C",X"63",X"81",X"33",X"33",X"81",X"32",X"08",X"08",X"0E",X"0E",X"0E",X"0E",X"32",X"87",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"56",X"81",X"5E",X"58",X"0A",X"2E",X"2E",X"58",X"58",X"33",X"2E",X"34",X"33",X"2E",X"2E",X"87",X"40",X"1C",X"1C",X"10",X"04",X"0A",X"10",X"64",X"3A",X"17",X"3A",X"3A",X"16",X"3B",X"0A",X"03",X"16",X"1C",X"1C",X"87",X"2D",X"0A",X"81",X"80",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"08",X"5D",X"80",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"56",X"AB",X"AB",X"AC",X"57",X"57",X"5D",X"87",X"80",X"5C",X"5C",X"5C",X"B1",X"D5",X"87",X"81",X"81",X"81",X"88",X"1C",X"1C",X"22",X"10",X"04",X"04",X"0A",X"34",X"34",X"10",X"0A",X"0A",X"10",X"10",X"03",X"10",X"22",X"1C",X"1C",X"87",X"2E",X"04",X"04",X"5D",X"80",X"31",X"08",X"0E",X"0E",X"08",X"08",X"D5",X"55",X"00",X"00",X"00",
X"00",X"00",X"06",X"5C",X"80",X"80",X"56",X"2B",X"2B",X"2A",X"2A",X"2A",X"80",X"0E",X"08",X"08",X"5C",X"AB",X"D5",X"57",X"04",X"04",X"57",X"88",X"1C",X"1C",X"1C",X"16",X"10",X"0A",X"0A",X"04",X"04",X"04",X"04",X"04",X"04",X"04",X"04",X"1C",X"1C",X"1C",X"1C",X"87",X"57",X"33",X"2E",X"2E",X"58",X"57",X"5C",X"32",X"07",X"08",X"AB",X"AA",X"00",X"00",X"00",X"00",
X"00",X"00",X"2A",X"55",X"2A",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"5D",X"08",X"0E",X"32",X"5C",X"0E",X"5C",X"81",X"04",X"04",X"57",X"6A",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"10",X"0A",X"04",X"04",X"04",X"04",X"10",X"22",X"1C",X"1C",X"1C",X"87",X"51",X"2D",X"87",X"80",X"57",X"81",X"AB",X"81",X"32",X"87",X"AA",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5C",X"38",X"0E",X"0E",X"0E",X"08",X"08",X"AA",X"D5",X"5D",X"04",X"81",X"6A",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"22",X"1C",X"10",X"0A",X"0A",X"10",X"1C",X"1C",X"1C",X"1C",X"1C",X"63",X"2D",X"04",X"AB",X"80",X"31",X"5C",X"5C",X"5D",X"87",X"D5",X"2B",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5C",X"32",X"08",X"0E",X"0E",X"32",X"AB",X"AB",X"AB",X"B1",X"81",X"64",X"1D",X"46",X"64",X"6A",X"40",X"1D",X"1C",X"1C",X"1C",X"1C",X"1C",X"22",X"1C",X"1C",X"22",X"1C",X"1C",X"1C",X"1C",X"1C",X"6A",X"57",X"2D",X"D4",X"5C",X"32",X"08",X"08",X"0E",X"32",X"80",X"AB",X"5C",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"7F",X"5D",X"07",X"08",X"32",X"5C",X"5C",X"32",X"32",X"0E",X"5C",X"8E",X"3A",X"34",X"2E",X"57",X"AB",X"8E",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"87",X"AA",X"5C",X"32",X"08",X"0E",X"0E",X"0E",X"08",X"56",X"55",X"80",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"D5",X"5D",X"08",X"0E",X"0E",X"08",X"0E",X"0E",X"08",X"5D",X"B1",X"A5",X"2E",X"04",X"04",X"57",X"A5",X"B1",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"1D",X"40",X"AA",X"07",X"08",X"0E",X"0E",X"0E",X"0E",X"08",X"80",X"00",X"00",X"2A",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"4F",X"D5",X"5D",X"08",X"0E",X"0E",X"0E",X"0E",X"32",X"32",X"32",X"AB",X"D5",X"87",X"04",X"57",X"2E",X"57",X"8D",X"1C",X"6A",X"6A",X"6A",X"40",X"1C",X"1C",X"1C",X"1C",X"1C",X"1C",X"40",X"63",X"64",X"B1",X"AA",X"08",X"0E",X"0E",X"0E",X"08",X"5C",X"AA",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B1",X"32",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"08",X"87",X"B1",X"B1",X"88",X"87",X"34",X"04",X"81",X"AB",X"81",X"57",X"81",X"87",X"8D",X"1C",X"1C",X"1C",X"1C",X"40",X"81",X"56",X"56",X"5C",X"87",X"5C",X"0E",X"0E",X"0E",X"08",X"B1",X"80",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"5C",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"32",X"87",X"32",X"32",X"5C",X"86",X"5D",X"04",X"0A",X"2E",X"04",X"04",X"04",X"04",X"7B",X"AB",X"40",X"1D",X"40",X"87",X"32",X"08",X"08",X"08",X"08",X"32",X"32",X"0E",X"08",X"5D",X"D5",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2A",X"80",X"32",X"08",X"0E",X"0E",X"0E",X"0E",X"32",X"32",X"08",X"0E",X"08",X"5C",X"81",X"04",X"04",X"04",X"0A",X"0A",X"0A",X"04",X"58",X"D4",X"86",X"1C",X"6A",X"5C",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"08",X"AB",X"AB",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5C",X"38",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"08",X"5C",X"5E",X"04",X"0A",X"0A",X"0A",X"0A",X"04",X"57",X"D5",X"32",X"5C",X"63",X"40",X"56",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"08",X"08",X"38",X"B1",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5C",X"38",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"08",X"0E",X"63",X"B1",X"33",X"04",X"0A",X"0A",X"0A",X"04",X"2E",X"B1",X"38",X"08",X"0E",X"80",X"87",X"32",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"5C",X"87",X"AB",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"87",X"08",X"08",X"0E",X"0E",X"08",X"08",X"0E",X"5D",X"B2",X"AB",X"86",X"2E",X"04",X"0A",X"0A",X"0A",X"04",X"87",X"87",X"32",X"0E",X"08",X"32",X"AA",X"32",X"08",X"0E",X"0E",X"32",X"32",X"08",X"AB",X"AA",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"87",X"38",X"32",X"32",X"5D",X"87",X"B1",X"AB",X"5C",X"00",X"5C",X"0A",X"04",X"04",X"0A",X"04",X"34",X"B1",X"86",X"AB",X"AB",X"5C",X"08",X"5C",X"5C",X"08",X"0E",X"08",X"32",X"81",X"5D",X"86",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"80",X"80",X"80",X"80",X"56",X"55",X"00",X"00",X"2A",X"5E",X"2E",X"AB",X"81",X"0A",X"04",X"81",X"55",X"00",X"2B",X"80",X"D5",X"86",X"0E",X"32",X"0E",X"0E",X"08",X"0E",X"80",X"80",X"55",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"88",X"AB",X"55",X"7F",X"5E",X"0A",X"86",X"00",X"00",X"00",X"00",X"55",X"CF",X"AB",X"32",X"08",X"08",X"08",X"63",X"80",X"00",X"06",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"AB",X"B1",X"2B",X"00",X"00",X"81",X"82",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"AB",X"87",X"5D",X"87",X"86",X"24",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"31",X"D6",X"2B",X"00",X"00",X"00",X"80",X"D6",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"55",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"AB",X"56",X"00",X"00",X"00",X"00",X"80",X"B1",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"55",X"AB",X"00",X"00",X"00",X"00",X"00",X"5C",X"80",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"87",X"2B",X"00",X"00",X"00",X"00",X"00",X"80",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"5C",X"00",X"00",X"00",X"00",X"00",X"00",X"80",X"2A",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5C",X"2B",X"00",X"00",X"00",X"00",X"00",X"2A",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"55",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00"
);
constant E1 : Array4 :=(
X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"2B",X"2B",X"31",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"32",X"32",X"32",X"56",X"5D",X"57",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"32",X"32",X"56",X"57",X"5D",X"57",X"57",X"57",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"57",X"57",X"57",X"57",X"57",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"57",X"57",X"57",X"57",X"57",X"58",X"5E",X"5E",X"5F",X"5D",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"32",X"57",X"5D",X"5D",X"33",X"33",X"2D",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"08",X"33",X"57",X"33",X"57",X"57",X"57",X"57",X"57",X"57",X"57",X"57",X"33",X"33",X"33",X"33",X"33",X"5E",X"2B",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"06",X"56",X"5D",X"58",X"33",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"02",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"02",X"2C",X"32",X"33",X"33",X"33",X"33",X"33",X"33",X"57",X"33",X"33",X"33",X"57",X"57",X"5D",X"57",X"5E",X"57",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2B",X"5E",X"5E",X"2D",X"2D",X"33",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"02",X"08",X"08",X"02",X"02",X"08",X"02",X"02",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"02",X"01",X"01",X"02",X"02",X"02",X"08",X"08",X"08",X"2C",X"57",X"33",X"33",X"33",X"33",X"33",X"88",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"5D",X"5E",X"33",X"57",X"5D",X"5D",X"2C",X"2C",X"2C",X"2C",X"2C",X"08",X"08",X"02",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"02",X"02",X"02",X"08",X"08",X"08",X"08",X"33",X"57",X"57",X"57",X"57",X"5D",X"82",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"32",X"5E",X"57",X"5D",X"2C",X"08",X"2C",X"2C",X"2C",X"08",X"08",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"08",X"08",X"02",X"08",X"08",X"08",X"2C",X"2C",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2B",X"5E",X"33",X"2C",X"2C",X"2C",X"08",X"08",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"2C",X"2C",X"2C",X"2C",X"33",X"5E",X"06",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"57",X"2C",X"08",X"08",X"08",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"2C",X"08",X"33",X"5E",X"56",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"57",X"57",X"57",X"2C",X"02",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"08",X"08",X"2C",X"2D",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"32",X"57",X"02",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"02",X"08",X"08",X"2C",X"32",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"32",X"2D",X"08",X"08",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"02",X"08",X"08",X"32",X"06",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"32",X"2C",X"08",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"02",X"08",X"32",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"33",X"02",X"02",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"08",X"2C",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"33",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"02",X"2C",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"33",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"08",X"02",X"2C",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"2C",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"02",X"01",X"2C",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"01",X"32",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"32",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"01",X"32",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"32",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"32",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"32",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"32",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"32",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"32",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"32",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"32",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"32",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"32",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"40",X"40",X"40",X"40",X"40",X"40",X"40",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"2C",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"47",X"47",X"47",X"47",X"01",X"01",X"01",X"01",X"01",X"01",X"47",X"40",X"01",X"01",X"01",X"40",X"47",X"01",X"01",X"01",X"01",X"40",X"47",X"47",X"40",X"47",X"47",X"47",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"56",X"32",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"47",X"40",X"40",X"40",X"40",X"01",X"01",X"01",X"01",X"01",X"47",X"40",X"01",X"01",X"01",X"40",X"47",X"01",X"01",X"01",X"01",X"40",X"47",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"32",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"40",X"47",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"2C",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"40",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"40",X"47",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"2C",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"47",X"40",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"2C",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"47",X"40",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"40",X"47",X"40",X"40",X"40",X"47",X"40",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"2C",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"47",X"40",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"40",X"47",X"40",X"40",X"40",X"40",X"40",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"2C",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"47",X"40",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"40",X"41",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"2C",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"47",X"40",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"2C",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"41",X"01",X"01",X"01",X"01",X"47",X"40",X"01",X"01",X"01",X"40",X"47",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"2C",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"47",X"01",X"01",X"01",X"47",X"41",X"01",X"01",X"01",X"01",X"47",X"47",X"01",X"01",X"01",X"40",X"41",X"01",X"01",X"01",X"01",X"40",X"40",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"2C",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"47",X"40",X"40",X"47",X"47",X"01",X"01",X"01",X"01",X"01",X"47",X"47",X"40",X"01",X"40",X"47",X"47",X"01",X"01",X"01",X"01",X"40",X"47",X"40",X"40",X"40",X"40",X"40",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"40",X"40",X"41",X"47",X"40",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"47",X"47",X"47",X"47",X"47",X"01",X"01",X"01",X"01",X"01",X"40",X"47",X"47",X"40",X"41",X"40",X"40",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"47",X"47",X"47",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"06",X"00",X"00",
X"00",X"00",X"00",X"2B",X"32",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"2C",X"06",X"00",X"00",
X"00",X"00",X"00",X"2B",X"32",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"02",X"2C",X"06",X"00",X"00",
X"00",X"00",X"00",X"06",X"32",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"02",X"02",X"2C",X"06",X"00",X"00",
X"00",X"00",X"00",X"00",X"2C",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"08",X"02",X"2C",X"06",X"00",X"00",
X"00",X"00",X"00",X"00",X"2C",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"02",X"2C",X"06",X"00",X"00",
X"00",X"00",X"00",X"00",X"2C",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"02",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2C",X"2C",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"02",X"02",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2B",X"2C",X"01",X"08",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"02",X"08",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2B",X"2C",X"01",X"08",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"08",X"08",X"08",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2B",X"2C",X"01",X"01",X"01",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"08",X"08",X"02",X"2C",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"32",X"5D",X"32",X"33",X"2C",X"01",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"08",X"08",X"08",X"02",X"2C",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"56",X"57",X"33",X"57",X"2C",X"01",X"02",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"01",X"2D",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"06",X"32",X"01",X"01",X"01",X"01",X"08",X"08",X"08",X"2C",X"2C",X"2C",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"2C",X"32",X"32",X"2C",X"2C",X"2C",X"08",X"02",X"01",X"33",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"57",X"33",X"57",X"57",X"57",X"57",X"57",X"57",X"57",X"57",X"57",X"2C",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"2C",X"57",X"57",X"57",X"57",X"57",X"57",X"57",X"57",X"33",X"5D",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"5D",X"5D",X"57",X"33",X"2C",X"2C",X"2C",X"08",X"08",X"08",X"08",X"08",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"2C",X"33",X"5D",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"32",X"02",X"08",X"08",X"08",X"02",X"02",X"02",X"02",X"08",X"02",X"02",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"08",X"08",X"08",X"02",X"08",X"2C",X"32",X"33",X"57",X"33",X"5D",X"5D",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2B",X"57",X"2C",X"2C",X"2C",X"2C",X"08",X"08",X"02",X"08",X"08",X"08",X"08",X"08",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"02",X"08",X"08",X"02",X"02",X"01",X"02",X"33",X"33",X"32",X"2C",X"08",X"33",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"56",X"57",X"2C",X"2C",X"2C",X"2C",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"02",X"01",X"01",X"01",X"01",X"01",X"02",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"08",X"01",X"01",X"01",X"01",X"01",X"02",X"08",X"08",X"2C",X"2C",X"32",X"32",X"2C",X"33",X"33",X"57",X"57",X"5D",X"07",X"00",X"00",X"00",
X"00",X"00",X"00",X"06",X"5D",X"2D",X"2C",X"2C",X"2C",X"2C",X"2C",X"08",X"08",X"02",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"01",X"2C",X"57",X"33",X"33",X"57",X"57",X"57",X"57",X"57",X"57",X"57",X"57",X"33",X"33",X"33",X"33",X"57",X"5E",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"32",X"2D",X"2C",X"2D",X"2D",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"2C",X"2C",X"2C",X"2C",X"08",X"08",X"02",X"02",X"01",X"01",X"01",X"01",X"01",X"01",X"01",X"32",X"57",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"08",X"08",X"08",X"02",X"33",X"5D",X"5D",X"5D",X"56",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"32",X"5E",X"5D",X"57",X"57",X"56",X"32",X"32",X"32",X"32",X"32",X"31",X"31",X"31",X"31",X"31",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"33",X"33",X"2C",X"2C",X"08",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"08",X"08",X"08",X"08",X"33",X"5D",X"57",X"5D",X"5E",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2B",X"56",X"2B",X"06",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2A",X"2B",X"2B",X"2B",X"31",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"33",X"57",X"57",X"57",X"57",X"57",X"57",X"33",X"57",X"57",X"5D",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"06",X"2A",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00"
);
constant pattern: Array1 :=(
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"07",X"01",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"56",X"81",X"88",X"AC",X"AC",X"AC",X"88",X"82",X"5D",X"56",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"82",X"AD",X"B3",X"B3",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"B3",X"B3",X"AD",X"88",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"5D",X"B3",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"88",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"B3",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"01",X"82",X"B3",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"AD",X"2C",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"AD",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"B3",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"B3",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"B3",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"B3",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"AD",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"B3",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"01",X"B3",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"B2",X"B3",X"01",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"D7",X"AC",X"AC",X"AC",X"AC",X"AD",X"AD",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"AD",X"AD",X"AD",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"01",X"B3",X"D7",X"B3",X"B3",X"AD",X"AC",X"AC",X"88",X"88",X"88",X"82",X"82",X"82",X"81",X"82",X"82",X"82",X"82",X"82",X"88",X"88",X"88",X"AC",X"AC",X"AD",X"AD",X"AD",X"AD",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"D7",X"88",X"82",X"81",X"81",X"5D",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"57",X"5D",X"81",X"82",X"88",X"AC",X"AD",X"B3",X"B3",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"2C",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"B3",X"81",X"5D",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"5D",X"81",X"88",X"88",X"AC",X"B3",X"B3",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"B3",X"81",X"56",X"81",X"81",X"81",X"81",X"5D",X"57",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"81",X"82",X"AC",X"B3",X"B3",X"AC",X"AC",X"AC",X"D7",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"56",X"AD",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"5D",X"57",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"81",X"88",X"AD",X"B3",X"AC",X"D7",X"81",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"32",X"B3",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"5D",X"57",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"5D",X"88",X"B3",X"D7",X"B3",X"07",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"AD",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"5D",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"55",X"55",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"57",X"5D",X"56",X"56",X"81",X"88",X"D7",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"82",X"AC",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"56",X"56",X"56",X"5D",X"81",X"88",X"AC",X"AC",X"88",X"88",X"82",X"81",X"5D",X"5D",X"5D",X"5D",X"81",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"5D",X"5D",X"81",X"81",X"56",X"56",X"88",X"AD",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"2C",X"AD",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"56",X"81",X"82",X"AC",X"D7",X"D7",X"AD",X"88",X"5D",X"33",X"33",X"32",X"0E",X"08",X"08",X"32",X"32",X"33",X"33",X"57",X"5D",X"5D",X"81",X"81",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"57",X"5D",X"81",X"81",X"81",X"81",X"81",X"56",X"88",X"82",X"00",X"00",X"00",X"00",
X"00",X"00",X"5D",X"AC",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"56",X"82",X"B3",X"D7",X"D7",X"88",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"32",X"33",X"5D",X"81",X"81",X"81",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"5D",X"5D",X"81",X"81",X"81",X"81",X"81",X"81",X"80",X"AD",X"5D",X"00",X"00",X"00",
X"00",X"2B",X"AC",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"88",X"D7",X"D7",X"88",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"08",X"33",X"5D",X"82",X"88",X"81",X"56",X"56",X"56",X"57",X"5D",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"AD",X"2B",X"00",X"00",
X"00",X"57",X"AD",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"AD",X"D7",X"D7",X"57",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"88",X"B3",X"AC",X"81",X"56",X"56",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"AC",X"5D",X"00",X"00",
X"00",X"5D",X"AC",X"81",X"81",X"81",X"81",X"81",X"81",X"B3",X"D7",X"D7",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"07",X"33",X"88",X"B3",X"AC",X"81",X"56",X"56",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"88",X"00",X"00",
X"00",X"81",X"AC",X"81",X"81",X"81",X"81",X"81",X"AD",X"D7",X"D7",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"32",X"89",X"D7",X"AC",X"81",X"56",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"AD",X"56",X"00",
X"00",X"82",X"88",X"81",X"81",X"81",X"81",X"88",X"B3",X"D7",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"57",X"B3",X"D7",X"88",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"AC",X"5D",X"00",
X"00",X"82",X"AC",X"81",X"81",X"81",X"81",X"B3",X"D7",X"B3",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"AD",X"D7",X"B3",X"88",X"81",X"81",X"81",X"81",X"81",X"AC",X"81",X"00",
X"00",X"81",X"AC",X"81",X"81",X"81",X"88",X"B3",X"D7",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"88",X"D7",X"B3",X"AD",X"81",X"81",X"81",X"81",X"81",X"82",X"00",
X"00",X"5D",X"AD",X"81",X"81",X"81",X"AD",X"D7",X"AD",X"08",X"08",X"08",X"07",X"08",X"07",X"08",X"08",X"08",X"08",X"07",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"B3",X"D7",X"B3",X"B3",X"88",X"81",X"81",X"81",X"82",X"00",
X"00",X"2B",X"AD",X"81",X"81",X"82",X"B3",X"D7",X"82",X"08",X"08",X"07",X"32",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"33",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"07",X"08",X"32",X"32",X"32",X"32",X"08",X"08",X"07",X"07",X"08",X"08",X"32",X"B3",X"D7",X"B3",X"B3",X"88",X"81",X"AC",X"81",X"00",
X"00",X"00",X"81",X"AC",X"81",X"88",X"B3",X"D7",X"5D",X"08",X"07",X"2C",X"5E",X"5D",X"32",X"08",X"08",X"08",X"08",X"32",X"57",X"82",X"5E",X"33",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"2C",X"5D",X"5D",X"5D",X"5E",X"5E",X"5E",X"5E",X"5D",X"5D",X"5D",X"57",X"08",X"08",X"08",X"39",X"D7",X"D6",X"B3",X"B3",X"88",X"AD",X"32",X"00",
X"00",X"00",X"2B",X"AD",X"81",X"88",X"B3",X"D7",X"5D",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"32",X"5E",X"5E",X"2C",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"5D",X"5E",X"57",X"32",X"08",X"07",X"07",X"07",X"08",X"08",X"2C",X"32",X"33",X"08",X"08",X"08",X"08",X"5E",X"D7",X"AC",X"B2",X"B3",X"B3",X"2C",X"00",
X"00",X"00",X"00",X"32",X"AD",X"AD",X"B3",X"D7",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"5D",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"5E",X"5E",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"08",X"08",X"07",X"07",X"07",X"08",X"08",X"08",X"08",X"0E",X"AD",X"D7",X"B3",X"D6",X"D7",X"32",X"00",
X"00",X"00",X"00",X"00",X"2B",X"B3",X"D7",X"D7",X"5D",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"33",X"33",X"57",X"5D",X"5E",X"5E",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"33",X"33",X"33",X"5D",X"32",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"D7",X"B3",X"D7",X"B3",X"07",X"00",
X"00",X"00",X"00",X"00",X"00",X"07",X"AC",X"D7",X"33",X"08",X"08",X"08",X"07",X"08",X"5D",X"5D",X"5D",X"B3",X"D7",X"B3",X"57",X"81",X"B3",X"5E",X"2C",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"5E",X"82",X"B3",X"B3",X"AD",X"56",X"88",X"88",X"5D",X"33",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"D7",X"B2",X"D7",X"88",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"07",X"32",X"88",X"57",X"08",X"08",X"82",X"D7",X"B3",X"88",X"AC",X"33",X"32",X"5E",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"88",X"33",X"07",X"B3",X"D7",X"B3",X"5D",X"AD",X"57",X"2C",X"5E",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"B3",X"D7",X"D7",X"2C",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"07",X"5D",X"33",X"08",X"08",X"07",X"08",X"57",X"5D",X"5E",X"5D",X"07",X"08",X"32",X"33",X"57",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"08",X"07",X"33",X"82",X"88",X"89",X"5D",X"07",X"07",X"08",X"5E",X"5D",X"07",X"08",X"08",X"08",X"08",X"08",X"33",X"B3",X"D7",X"82",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"57",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"5D",X"32",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"33",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"39",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0F",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0F",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0F",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"07",X"5D",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0F",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"33",X"5E",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"33",X"82",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0F",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"32",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"07",X"07",X"07",X"01",X"33",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"5D",X"07",X"08",X"08",X"08",X"07",X"08",X"5E",X"5D",X"57",X"32",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"0F",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"5D",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"32",X"33",X"57",X"5D",X"5D",X"08",X"07",X"5E",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"2C",X"5E",X"07",X"08",X"08",X"08",X"08",X"08",X"2C",X"32",X"57",X"5D",X"5E",X"2C",X"07",X"08",X"08",X"08",X"08",X"08",X"0F",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"57",X"5D",X"5E",X"5D",X"5D",X"33",X"33",X"08",X"01",X"32",X"88",X"32",X"08",X"08",X"08",X"08",X"08",X"07",X"2C",X"5E",X"57",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"57",X"88",X"08",X"07",X"08",X"08",X"08",X"08",X"0F",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"07",X"32",X"88",X"5D",X"32",X"08",X"07",X"08",X"07",X"07",X"08",X"08",X"07",X"32",X"5E",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"57",X"07",X"08",X"08",X"08",X"08",X"07",X"08",X"07",X"32",X"57",X"5D",X"07",X"33",X"5D",X"08",X"08",X"08",X"08",X"08",X"33",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"08",X"5E",X"32",X"08",X"07",X"07",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"2C",X"33",X"5D",X"5D",X"33",X"32",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"2C",X"57",X"5D",X"5E",X"89",X"89",X"07",X"32",X"5D",X"07",X"08",X"08",X"08",X"08",X"3A",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"07",X"33",X"5D",X"08",X"33",X"88",X"5D",X"5D",X"32",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"07",X"07",X"08",X"08",X"08",X"07",X"08",X"32",X"5D",X"5E",X"5E",X"39",X"0F",X"5E",X"2C",X"08",X"33",X"5D",X"08",X"08",X"08",X"08",X"08",X"5E",X"56",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"07",X"2C",X"5E",X"2C",X"2C",X"89",X"3A",X"5E",X"64",X"5E",X"5D",X"57",X"32",X"2C",X"07",X"08",X"08",X"08",X"07",X"07",X"07",X"07",X"08",X"08",X"08",X"32",X"5D",X"88",X"5E",X"0F",X"0E",X"08",X"64",X"5D",X"08",X"07",X"5E",X"33",X"07",X"08",X"08",X"08",X"08",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"07",X"33",X"33",X"08",X"57",X"5E",X"08",X"0E",X"0F",X"39",X"5E",X"5E",X"5E",X"5D",X"5D",X"57",X"57",X"33",X"32",X"33",X"57",X"5D",X"5D",X"5E",X"5E",X"3A",X"0F",X"0E",X"0F",X"0E",X"3A",X"82",X"07",X"08",X"5D",X"5E",X"08",X"08",X"08",X"08",X"08",X"33",X"57",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"08",X"07",X"5E",X"0F",X"0E",X"0F",X"0E",X"0E",X"0E",X"0F",X"39",X"3A",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"3A",X"0F",X"0E",X"0E",X"0F",X"0F",X"0E",X"33",X"88",X"08",X"08",X"32",X"5E",X"07",X"07",X"08",X"08",X"08",X"08",X"5E",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"32",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"57",X"64",X"0E",X"0F",X"0F",X"0F",X"0F",X"0E",X"0E",X"08",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0E",X"0F",X"0F",X"0F",X"0F",X"0E",X"0F",X"89",X"32",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"33",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"82",X"39",X"0E",X"0F",X"0E",X"39",X"5E",X"5E",X"5E",X"0F",X"0E",X"0E",X"0E",X"0F",X"0E",X"0F",X"0F",X"0F",X"0F",X"0F",X"0E",X"0F",X"88",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"2C",X"88",X"0F",X"0E",X"5E",X"5D",X"5C",X"38",X"5C",X"88",X"39",X"3A",X"64",X"64",X"5E",X"0F",X"0E",X"0F",X"0F",X"0E",X"0F",X"89",X"57",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"3A",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"57",X"64",X"3A",X"5D",X"0D",X"0D",X"0D",X"0D",X"38",X"88",X"5D",X"38",X"32",X"5D",X"88",X"33",X"0E",X"0E",X"0F",X"88",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"88",X"24",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"89",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"B3",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"32",X"88",X"0F",X"0F",X"89",X"57",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0E",X"88",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"88",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"82",X"64",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"38",X"89",X"64",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0E",X"89",X"2C",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"88",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"5E",X"88",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"0D",X"B3",X"88",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0F",X"89",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"57",X"88",X"5D",X"38",X"0D",X"0D",X"0D",X"32",X"5D",X"88",X"88",X"57",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"88",X"2C",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"82",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"82",X"88",X"88",X"88",X"88",X"82",X"57",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"88",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"07",X"2C",X"33",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"5E",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"82",X"33",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0F",X"5E",X"88",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"5E",X"33",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0F",X"5E",X"5E",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"82",X"5E",X"32",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"5E",X"88",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"5D",X"5E",X"33",X"08",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"33",X"5E",X"5E",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"81",X"5E",X"5E",X"3A",X"33",X"33",X"3A",X"5E",X"5E",X"81",X"56",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"32",X"56",X"56",X"56",X"56",X"56",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00"
);

constant pattern2: Array1 :=(
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"56",X"56",X"56",X"32",X"2B",X"07",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"AC",X"B3",X"B3",X"B3",X"B3",X"B3",X"AD",X"AC",X"88",X"5D",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"B3",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"B3",X"82",X"2C",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"01",X"5D",X"B3",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"B3",X"B3",X"82",X"07",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"B3",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"B3",X"57",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"82",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"AD",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"B3",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"AD",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"B3",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"AD",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"82",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AD",X"AD",X"AD",X"AD",X"AD",X"AD",X"AD",X"AD",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"AC",X"D7",X"B3",X"B3",X"AD",X"AD",X"AC",X"AC",X"88",X"88",X"88",X"82",X"82",X"82",X"82",X"82",X"82",X"88",X"88",X"88",X"AC",X"AC",X"AD",X"AD",X"AD",X"AD",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"D7",X"AC",X"88",X"82",X"81",X"5D",X"5D",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"5D",X"5D",X"81",X"88",X"88",X"AD",X"B3",X"B3",X"AD",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"AD",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"B3",X"88",X"5D",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"57",X"5D",X"82",X"88",X"AC",X"AD",X"B3",X"B3",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"AD",X"88",X"56",X"81",X"81",X"81",X"81",X"5D",X"57",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"5D",X"81",X"88",X"AD",X"B3",X"B3",X"AC",X"AC",X"D7",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2B",X"AD",X"81",X"7A",X"81",X"81",X"81",X"81",X"81",X"5D",X"57",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"57",X"81",X"88",X"B3",X"B3",X"AC",X"D7",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2B",X"AD",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"5D",X"57",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"81",X"88",X"B3",X"D7",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"88",X"AC",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"5D",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"5D",X"5D",X"56",X"56",X"81",X"AD",X"D7",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"5D",X"AD",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"56",X"56",X"5D",X"81",X"82",X"AC",X"AC",X"88",X"88",X"82",X"5D",X"5D",X"57",X"57",X"57",X"57",X"5D",X"5D",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"5D",X"5D",X"81",X"81",X"56",X"81",X"AD",X"81",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"2B",X"AC",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"56",X"81",X"88",X"B3",X"D7",X"B3",X"88",X"5D",X"33",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"32",X"32",X"33",X"57",X"5D",X"5D",X"81",X"7A",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"57",X"5D",X"81",X"81",X"81",X"81",X"81",X"7A",X"AC",X"57",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"5D",X"AC",X"81",X"81",X"81",X"81",X"81",X"81",X"80",X"5D",X"88",X"B3",X"D7",X"B3",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"32",X"33",X"5D",X"82",X"81",X"81",X"56",X"56",X"56",X"56",X"56",X"56",X"5D",X"5D",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"AD",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"82",X"88",X"81",X"81",X"81",X"81",X"81",X"80",X"81",X"AD",X"D7",X"D7",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"32",X"33",X"5E",X"88",X"AC",X"81",X"56",X"56",X"56",X"5D",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"AC",X"81",X"00",X"00",X"00",X"00",
X"00",X"2B",X"AC",X"81",X"81",X"81",X"81",X"81",X"81",X"82",X"B3",X"D7",X"AC",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"32",X"5E",X"89",X"AD",X"81",X"56",X"56",X"5C",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"AC",X"2B",X"00",X"00",X"00",
X"00",X"32",X"AC",X"81",X"81",X"81",X"81",X"81",X"82",X"B3",X"D7",X"AC",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"AD",X"B3",X"82",X"5D",X"56",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"AC",X"81",X"00",X"00",X"00",
X"00",X"56",X"AC",X"81",X"81",X"81",X"81",X"81",X"AD",X"D7",X"B3",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"07",X"5E",X"D7",X"B3",X"82",X"56",X"80",X"81",X"81",X"81",X"81",X"81",X"81",X"88",X"00",X"00",X"00",
X"00",X"56",X"AC",X"81",X"81",X"81",X"81",X"88",X"B3",X"D7",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"32",X"88",X"2C",X"08",X"08",X"08",X"08",X"08",X"32",X"AD",X"D7",X"AC",X"81",X"81",X"81",X"81",X"81",X"81",X"81",X"AC",X"2B",X"00",X"00",
X"00",X"56",X"AC",X"81",X"81",X"81",X"82",X"B3",X"D7",X"AC",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"B3",X"B3",X"AD",X"82",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"33",X"89",X"B3",X"D7",X"88",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"88",X"D7",X"B3",X"88",X"81",X"81",X"81",X"81",X"81",X"AC",X"32",X"00",X"00",
X"00",X"32",X"AC",X"81",X"81",X"81",X"88",X"B3",X"D7",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"82",X"88",X"88",X"89",X"B3",X"D7",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"88",X"D7",X"88",X"82",X"8F",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"88",X"D7",X"B3",X"AD",X"82",X"81",X"81",X"81",X"AC",X"56",X"00",X"00",
X"00",X"2B",X"AC",X"81",X"81",X"81",X"AC",X"D7",X"AC",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"88",X"33",X"07",X"82",X"D7",X"B3",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"32",X"B3",X"B3",X"5E",X"32",X"5D",X"6B",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"D7",X"D7",X"B3",X"88",X"81",X"81",X"AC",X"32",X"00",X"00",
X"00",X"00",X"82",X"AC",X"81",X"81",X"AD",X"D7",X"82",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"2C",X"8F",X"5D",X"08",X"08",X"32",X"B3",X"B3",X"08",X"2C",X"32",X"07",X"2C",X"07",X"33",X"B3",X"5E",X"08",X"32",X"B3",X"65",X"41",X"89",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"B3",X"D7",X"B2",X"B3",X"88",X"81",X"88",X"2B",X"00",X"00",
X"00",X"00",X"2B",X"B3",X"81",X"82",X"B3",X"D7",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"33",X"88",X"6B",X"5E",X"07",X"08",X"08",X"08",X"88",X"B3",X"5E",X"2C",X"08",X"32",X"88",X"89",X"33",X"08",X"08",X"88",X"B3",X"41",X"41",X"B3",X"57",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"D7",X"D7",X"B3",X"B3",X"B3",X"82",X"00",X"00",X"00",
X"00",X"00",X"00",X"56",X"B3",X"88",X"B3",X"D7",X"5E",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"AD",X"8F",X"41",X"B3",X"2C",X"07",X"08",X"07",X"08",X"88",X"82",X"07",X"07",X"33",X"89",X"2C",X"08",X"07",X"32",X"65",X"3B",X"17",X"65",X"B3",X"57",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"D7",X"AD",X"B2",X"D7",X"88",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"56",X"B3",X"D7",X"D7",X"5E",X"08",X"08",X"08",X"08",X"07",X"07",X"5D",X"B3",X"41",X"41",X"D7",X"33",X"08",X"07",X"08",X"08",X"07",X"07",X"08",X"08",X"08",X"07",X"07",X"08",X"08",X"57",X"5F",X"11",X"3B",X"3B",X"89",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0F",X"B3",X"D7",X"B3",X"D7",X"88",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2C",X"B3",X"D7",X"5D",X"08",X"08",X"08",X"08",X"2C",X"5D",X"88",X"3B",X"11",X"5F",X"89",X"AD",X"5E",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"5D",X"88",X"5F",X"0B",X"35",X"11",X"5F",X"AD",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"88",X"D7",X"B2",X"D7",X"57",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"5D",X"08",X"08",X"07",X"08",X"5E",X"24",X"56",X"3B",X"11",X"11",X"34",X"56",X"81",X"5D",X"33",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"56",X"2A",X"5E",X"0B",X"0B",X"0B",X"89",X"AC",X"81",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"D7",X"D7",X"AD",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"5D",X"08",X"08",X"08",X"5D",X"5D",X"00",X"2B",X"89",X"0B",X"35",X"82",X"88",X"81",X"00",X"5D",X"08",X"33",X"32",X"07",X"08",X"08",X"08",X"33",X"5D",X"00",X"00",X"81",X"89",X"59",X"83",X"AD",X"82",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"D7",X"D7",X"56",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"5D",X"08",X"08",X"08",X"08",X"5E",X"2C",X"00",X"2B",X"5F",X"AD",X"B3",X"B3",X"56",X"24",X"5D",X"08",X"5D",X"32",X"07",X"08",X"08",X"08",X"08",X"5D",X"56",X"00",X"01",X"B3",X"D7",X"B3",X"B3",X"32",X"00",X"5D",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"88",X"5D",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"5D",X"08",X"08",X"08",X"07",X"08",X"5E",X"57",X"2B",X"81",X"B3",X"B3",X"88",X"57",X"5E",X"08",X"08",X"5D",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"5D",X"2C",X"5D",X"B3",X"B3",X"AC",X"56",X"5E",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"32",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"07",X"07",X"32",X"33",X"33",X"33",X"33",X"32",X"08",X"07",X"08",X"57",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"33",X"32",X"57",X"33",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"32",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"07",X"08",X"08",X"07",X"08",X"08",X"08",X"5E",X"32",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"2A",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"32",X"07",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"33",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"57",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"88",X"2C",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"57",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"5E",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2A",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"33",X"5E",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"81",X"2C",X"07",X"08",X"08",X"08",X"08",X"07",X"32",X"57",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"33",X"57",X"08",X"08",X"08",X"08",X"08",X"07",X"57",X"5E",X"32",X"07",X"07",X"07",X"08",X"07",X"08",X"5E",X"5D",X"07",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"5E",X"5D",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"07",X"08",X"08",X"08",X"08",X"08",X"07",X"5D",X"88",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"33",X"82",X"5E",X"5D",X"57",X"57",X"5D",X"82",X"5D",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"5E",X"33",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"56",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"07",X"08",X"08",X"08",X"08",X"07",X"33",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"01",X"07",X"32",X"33",X"33",X"33",X"33",X"08",X"01",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"33",X"5D",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"07",X"08",X"08",X"08",X"08",X"08",X"5D",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"01",X"01",X"01",X"01",X"01",X"01",X"07",X"07",X"07",X"01",X"01",X"07",X"07",X"08",X"08",X"08",X"07",X"32",X"5D",X"07",X"08",X"08",X"08",X"08",X"08",X"0F",X"5E",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"07",X"08",X"08",X"08",X"08",X"07",X"5D",X"32",X"08",X"08",X"08",X"07",X"07",X"07",X"07",X"08",X"08",X"33",X"33",X"5D",X"5D",X"5E",X"5E",X"5D",X"5D",X"57",X"57",X"5E",X"5E",X"5D",X"5D",X"33",X"07",X"07",X"08",X"07",X"33",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"39",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"07",X"08",X"08",X"08",X"08",X"08",X"5D",X"33",X"07",X"08",X"07",X"08",X"39",X"5D",X"5D",X"5D",X"57",X"5D",X"57",X"56",X"56",X"56",X"32",X"2B",X"2B",X"81",X"56",X"2B",X"32",X"56",X"57",X"5D",X"5D",X"08",X"08",X"07",X"32",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"08",X"08",X"08",X"08",X"08",X"07",X"32",X"33",X"07",X"07",X"33",X"5D",X"32",X"2C",X"2B",X"2B",X"56",X"00",X"00",X"07",X"00",X"00",X"00",X"00",X"00",X"32",X"56",X"00",X"00",X"00",X"00",X"00",X"56",X"5D",X"08",X"08",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"33",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"33",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"08",X"07",X"32",X"5D",X"00",X"00",X"00",X"00",X"82",X"56",X"2B",X"88",X"57",X"56",X"2B",X"00",X"2B",X"57",X"88",X"57",X"57",X"2B",X"00",X"00",X"56",X"33",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"82",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"56",X"2B",X"5D",X"57",X"57",X"88",X"32",X"56",X"82",X"2B",X"00",X"00",X"07",X"00",X"5D",X"57",X"00",X"00",X"00",X"00",X"57",X"33",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"82",X"56",X"2B",X"00",X"00",X"32",X"07",X"00",X"2C",X"00",X"00",X"00",X"00",X"00",X"2B",X"2B",X"00",X"00",X"00",X"2A",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"88",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"5D",X"00",X"00",X"00",X"00",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2C",X"2B",X"2B",X"32",X"32",X"32",X"5D",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"64",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"5E",X"57",X"5D",X"57",X"57",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"57",X"57",X"57",X"33",X"33",X"33",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"57",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"88",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"82",X"39",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0F",X"64",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"5E",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"3A",X"82",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"82",X"39",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"89",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"5E",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"0F",X"5E",X"5D",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"5E",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"3A",X"5E",X"5D",X"2C",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"5E",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"5E",X"57",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"5E",X"3A",X"33",X"0F",X"0F",X"0F",X"33",X"3A",X"5E",X"82",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"56",X"57",X"5D",X"5D",X"5D",X"57",X"56",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00"
);

constant pattern3: Array1 :=(
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"01",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"56",X"2B",X"2B",X"2B",X"81",X"AC",X"AC",X"81",X"81",X"AC",X"AC",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"81",X"AC",X"D7",X"D7",X"AC",X"D7",X"D7",X"D7",X"D7",X"D7",X"D7",X"D7",X"D7",X"D7",X"81",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"AC",X"D7",X"D7",X"D7",X"D7",X"D7",X"D7",X"D7",X"D1",X"AC",X"AC",X"D1",X"D1",X"AC",X"D1",X"D7",X"D7",X"AC",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"81",X"AC",X"AC",X"D7",X"D7",X"D7",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D1",X"AD",X"AD",X"D1",X"AC",X"D7",X"D7",X"D7",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"AC",X"D7",X"D7",X"D7",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D1",X"AC",X"AC",X"D1",X"AC",X"AD",X"AC",X"D7",X"AC",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"81",X"D7",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"D7",X"AC",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"AC",X"D7",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D1",X"D7",X"AC",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"D7",X"D7",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"D7",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"25",X"AC",X"D7",X"AC",X"AC",X"AC",X"AC",X"AD",X"AC",X"AC",X"AD",X"AC",X"AC",X"AC",X"AC",X"AD",X"AD",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AD",X"AC",X"D1",X"AC",X"AC",X"AC",X"AC",X"AC",X"AD",X"D7",X"D7",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"D7",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D0",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D1",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D7",X"AC",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"AC",X"D7",X"AC",X"AC",X"AC",X"AC",X"D7",X"D7",X"D0",X"D7",X"D0",X"AC",X"AC",X"D7",X"D7",X"D7",X"D7",X"D7",X"D7",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D6",X"AC",X"AC",X"AC",X"AC",X"D7",X"D7",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"AC",X"D7",X"AC",X"D7",X"D7",X"D7",X"AC",X"AC",X"D1",X"AC",X"81",X"81",X"7B",X"81",X"AC",X"81",X"81",X"81",X"AC",X"D7",X"D7",X"D7",X"AC",X"D7",X"D1",X"AC",X"AC",X"AC",X"AC",X"AC",X"D0",X"D7",X"AC",X"D7",X"AC",X"D7",X"AC",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"81",X"D7",X"AD",X"AC",X"AC",X"AC",X"81",X"56",X"56",X"56",X"2C",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"56",X"57",X"81",X"81",X"7B",X"81",X"AC",X"D7",X"D7",X"D7",X"D1",X"AC",X"AC",X"AC",X"D0",X"AC",X"AC",X"D7",X"AC",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"81",X"D7",X"AC",X"81",X"56",X"56",X"56",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"56",X"81",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"D1",X"AC",X"AC",X"AD",X"D7",X"81",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"81",X"AC",X"82",X"56",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2C",X"2B",X"2B",X"2B",X"2B",X"56",X"2B",X"2B",X"2C",X"56",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"56",X"81",X"AC",X"D7",X"D7",X"AC",X"AC",X"AC",X"D7",X"D7",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"AC",X"81",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"50",X"2B",X"2B",X"2B",X"50",X"56",X"56",X"50",X"2B",X"56",X"56",X"2B",X"2B",X"2C",X"56",X"2C",X"2C",X"2B",X"2B",X"2B",X"2B",X"56",X"57",X"82",X"AC",X"AC",X"D7",X"D7",X"AC",X"D7",X"81",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2B",X"AC",X"AC",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"56",X"56",X"81",X"AC",X"AC",X"81",X"81",X"AC",X"AC",X"AC",X"56",X"81",X"AC",X"81",X"56",X"2B",X"2C",X"56",X"2B",X"2B",X"2C",X"2B",X"2C",X"2C",X"2B",X"2B",X"56",X"81",X"AC",X"D7",X"D7",X"D7",X"AC",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2B",X"81",X"56",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"56",X"81",X"AC",X"AC",X"AC",X"AC",X"D7",X"D7",X"AC",X"AC",X"D7",X"D7",X"D7",X"AC",X"AD",X"D7",X"D7",X"AC",X"81",X"81",X"AC",X"56",X"56",X"56",X"56",X"56",X"2C",X"2C",X"2B",X"2B",X"2B",X"2C",X"81",X"AC",X"D7",X"D7",X"AC",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"82",X"81",X"2B",X"2B",X"2B",X"2B",X"2B",X"56",X"81",X"81",X"81",X"AC",X"D7",X"D7",X"D7",X"D7",X"D7",X"D7",X"AD",X"AC",X"AD",X"AD",X"AC",X"AD",X"D7",X"D7",X"D7",X"D7",X"AC",X"D7",X"D7",X"AC",X"AC",X"81",X"56",X"56",X"2B",X"56",X"2C",X"2B",X"56",X"56",X"2B",X"56",X"81",X"82",X"D7",X"AC",X"81",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"56",X"81",X"2B",X"2B",X"2B",X"2B",X"2B",X"56",X"81",X"D7",X"D7",X"D7",X"AC",X"AD",X"D7",X"D7",X"AC",X"AC",X"AC",X"81",X"57",X"5D",X"81",X"5D",X"56",X"81",X"88",X"88",X"AC",X"AD",X"D7",X"D7",X"D7",X"D7",X"AC",X"AC",X"AC",X"56",X"56",X"56",X"2C",X"56",X"56",X"50",X"56",X"2C",X"2B",X"81",X"D7",X"D7",X"AC",X"2B",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"2B",X"2B",X"2B",X"2B",X"56",X"81",X"AC",X"AC",X"D7",X"D6",X"D7",X"D7",X"B3",X"AD",X"88",X"57",X"32",X"32",X"32",X"2C",X"2C",X"32",X"2C",X"08",X"2C",X"32",X"32",X"32",X"57",X"82",X"AC",X"AC",X"AD",X"D7",X"D7",X"D7",X"D0",X"81",X"56",X"50",X"56",X"2C",X"56",X"2C",X"2B",X"2C",X"32",X"81",X"AC",X"D1",X"AC",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"2B",X"2B",X"2B",X"56",X"81",X"D7",X"D7",X"D7",X"AC",X"D7",X"D7",X"B3",X"82",X"57",X"32",X"08",X"08",X"08",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"08",X"08",X"08",X"07",X"08",X"2C",X"32",X"32",X"5D",X"88",X"AC",X"D7",X"D7",X"AC",X"81",X"82",X"81",X"56",X"56",X"2B",X"2B",X"56",X"32",X"56",X"56",X"57",X"D7",X"81",X"00",X"00",X"00",X"00",
X"00",X"00",X"2B",X"2B",X"2B",X"2B",X"56",X"A6",X"AC",X"AC",X"AC",X"AC",X"D7",X"D7",X"AC",X"5D",X"2C",X"08",X"08",X"2C",X"2C",X"08",X"08",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"08",X"08",X"2C",X"08",X"07",X"07",X"2C",X"32",X"57",X"81",X"AC",X"D7",X"D7",X"D7",X"AC",X"81",X"56",X"2B",X"56",X"50",X"56",X"56",X"2C",X"56",X"81",X"AC",X"82",X"2B",X"00",X"00",
X"00",X"2B",X"50",X"56",X"2B",X"56",X"AC",X"D7",X"D7",X"D0",X"D1",X"D7",X"D7",X"88",X"56",X"2C",X"2C",X"2C",X"2B",X"2B",X"07",X"07",X"07",X"07",X"07",X"07",X"2B",X"2B",X"2B",X"07",X"07",X"07",X"07",X"07",X"07",X"08",X"2C",X"2C",X"2C",X"32",X"57",X"82",X"B3",X"D7",X"D7",X"AC",X"56",X"81",X"56",X"2B",X"56",X"56",X"56",X"56",X"56",X"81",X"AC",X"81",X"00",X"00",
X"00",X"2B",X"2C",X"2B",X"2B",X"81",X"AD",X"D7",X"D7",X"D6",X"D7",X"D7",X"82",X"32",X"2C",X"2C",X"2C",X"2C",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"07",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"81",X"AC",X"D7",X"AD",X"AD",X"D7",X"AC",X"81",X"56",X"2B",X"56",X"56",X"56",X"56",X"57",X"81",X"00",X"00",
X"01",X"2C",X"2B",X"2B",X"57",X"AC",X"D7",X"B3",X"B3",X"D7",X"D7",X"88",X"32",X"2C",X"32",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"2C",X"2B",X"07",X"07",X"2B",X"2B",X"07",X"2B",X"2B",X"2B",X"2B",X"2B",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"32",X"57",X"82",X"D7",X"D7",X"D7",X"D7",X"AC",X"56",X"56",X"56",X"56",X"56",X"56",X"56",X"2B",X"00",X"00",
X"2B",X"56",X"2C",X"2B",X"81",X"D7",X"D7",X"D6",X"D7",X"D7",X"AD",X"57",X"32",X"57",X"57",X"57",X"5D",X"5D",X"5D",X"57",X"33",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"57",X"57",X"57",X"57",X"88",X"B3",X"B3",X"D7",X"AC",X"AC",X"AC",X"56",X"56",X"2C",X"56",X"56",X"2B",X"00",X"00",
X"00",X"2B",X"2C",X"56",X"AC",X"D1",X"D7",X"D0",X"D7",X"D7",X"82",X"5D",X"5D",X"5E",X"5D",X"5D",X"5D",X"5D",X"82",X"82",X"5D",X"57",X"33",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"33",X"57",X"5D",X"5D",X"5D",X"82",X"5D",X"5D",X"5D",X"5D",X"5D",X"5E",X"82",X"5D",X"5D",X"81",X"AD",X"D7",X"D7",X"D7",X"D7",X"AC",X"56",X"2B",X"56",X"56",X"2B",X"00",X"00",
X"2B",X"50",X"2B",X"81",X"D7",X"D7",X"D0",X"D7",X"D7",X"AD",X"81",X"5D",X"5D",X"33",X"32",X"57",X"5D",X"5D",X"82",X"82",X"82",X"82",X"5D",X"33",X"32",X"32",X"2C",X"32",X"32",X"57",X"57",X"5D",X"5D",X"5E",X"82",X"82",X"82",X"82",X"81",X"5D",X"5D",X"57",X"5D",X"5D",X"5D",X"5D",X"5D",X"88",X"D7",X"D7",X"D0",X"D7",X"D7",X"81",X"56",X"56",X"56",X"2B",X"00",X"00",
X"2B",X"57",X"56",X"81",X"AD",X"D7",X"D6",X"D7",X"D7",X"AC",X"5D",X"57",X"32",X"32",X"57",X"5D",X"82",X"88",X"AC",X"AC",X"AC",X"82",X"81",X"5D",X"32",X"2C",X"2C",X"2C",X"32",X"33",X"57",X"5D",X"5D",X"82",X"82",X"88",X"88",X"82",X"82",X"81",X"5D",X"32",X"32",X"33",X"57",X"57",X"5D",X"82",X"AC",X"D7",X"D7",X"D7",X"D7",X"D7",X"AC",X"81",X"56",X"2C",X"00",X"00",
X"01",X"56",X"57",X"82",X"AC",X"D0",X"D0",X"D7",X"D7",X"88",X"33",X"2C",X"33",X"5E",X"88",X"82",X"81",X"AC",X"AC",X"AC",X"AC",X"81",X"5D",X"57",X"32",X"2C",X"2C",X"32",X"32",X"32",X"57",X"82",X"82",X"82",X"82",X"81",X"57",X"81",X"AC",X"AD",X"AC",X"88",X"5D",X"57",X"32",X"33",X"57",X"5D",X"82",X"AD",X"D7",X"D7",X"D7",X"D7",X"D7",X"AC",X"81",X"2B",X"00",X"00",
X"00",X"2C",X"81",X"AD",X"D7",X"D0",X"D6",X"D7",X"D7",X"82",X"32",X"33",X"5D",X"5E",X"57",X"32",X"32",X"57",X"81",X"81",X"5D",X"57",X"57",X"32",X"32",X"32",X"32",X"32",X"33",X"57",X"5D",X"82",X"5D",X"5D",X"5D",X"56",X"2B",X"32",X"81",X"AC",X"88",X"81",X"82",X"82",X"5D",X"57",X"57",X"57",X"5D",X"AC",X"D7",X"B3",X"B2",X"D7",X"D1",X"D7",X"81",X"01",X"00",X"00",
X"00",X"56",X"AC",X"AC",X"D7",X"D7",X"D7",X"D7",X"D7",X"82",X"2C",X"33",X"33",X"32",X"2C",X"2C",X"2C",X"07",X"2C",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"5D",X"5E",X"5D",X"32",X"32",X"32",X"32",X"32",X"2C",X"2C",X"32",X"32",X"32",X"32",X"5D",X"5E",X"5D",X"57",X"33",X"57",X"5D",X"AC",X"D7",X"D7",X"D6",X"D1",X"D7",X"81",X"00",X"00",X"00",
X"00",X"2B",X"AC",X"D7",X"D7",X"D7",X"D7",X"D7",X"D7",X"81",X"2C",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"2C",X"32",X"32",X"2C",X"2C",X"32",X"33",X"5D",X"5D",X"33",X"32",X"32",X"2C",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"32",X"32",X"33",X"33",X"33",X"33",X"33",X"32",X"57",X"82",X"B3",X"D7",X"D6",X"D7",X"D7",X"56",X"00",X"00",X"00",
X"00",X"00",X"81",X"D7",X"D7",X"D7",X"D7",X"D7",X"D7",X"5D",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"32",X"32",X"2C",X"32",X"32",X"57",X"5D",X"5D",X"33",X"32",X"33",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"33",X"57",X"82",X"AC",X"D7",X"D7",X"AC",X"81",X"2B",X"00",X"00",X"00",
X"00",X"00",X"81",X"D7",X"D7",X"D7",X"D6",X"D7",X"B3",X"57",X"2C",X"2C",X"2C",X"08",X"2C",X"2C",X"2C",X"08",X"2C",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"2C",X"32",X"33",X"57",X"5D",X"57",X"33",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"33",X"33",X"57",X"82",X"88",X"AC",X"D7",X"AC",X"81",X"2C",X"00",X"00",X"00",
X"00",X"00",X"81",X"D7",X"D7",X"D7",X"D7",X"D7",X"AD",X"57",X"2C",X"2C",X"08",X"08",X"08",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"2C",X"2C",X"32",X"33",X"57",X"5D",X"33",X"32",X"32",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"2C",X"08",X"2C",X"32",X"32",X"32",X"33",X"33",X"5D",X"82",X"82",X"AC",X"AD",X"AC",X"AC",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"81",X"D7",X"D7",X"D7",X"D7",X"AC",X"32",X"2C",X"2C",X"08",X"07",X"08",X"08",X"08",X"2C",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"2C",X"2C",X"32",X"33",X"57",X"5D",X"33",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"08",X"2C",X"2C",X"32",X"33",X"33",X"33",X"57",X"82",X"82",X"88",X"AC",X"D7",X"81",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"56",X"AC",X"D7",X"D7",X"82",X"2C",X"08",X"08",X"2C",X"07",X"07",X"08",X"08",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"2C",X"2C",X"08",X"32",X"33",X"57",X"5D",X"57",X"33",X"33",X"32",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"08",X"08",X"2C",X"32",X"33",X"33",X"33",X"57",X"5D",X"82",X"88",X"AC",X"AC",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"2B",X"AC",X"D7",X"5D",X"2C",X"08",X"08",X"2C",X"07",X"07",X"07",X"08",X"2C",X"2C",X"32",X"32",X"32",X"32",X"2C",X"08",X"08",X"32",X"33",X"57",X"5D",X"57",X"33",X"33",X"33",X"32",X"2C",X"2C",X"08",X"08",X"08",X"2C",X"2C",X"08",X"08",X"2C",X"2C",X"32",X"33",X"33",X"57",X"5D",X"82",X"88",X"AC",X"81",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"81",X"57",X"08",X"08",X"08",X"07",X"07",X"07",X"08",X"32",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"07",X"07",X"2C",X"33",X"57",X"57",X"32",X"32",X"33",X"33",X"33",X"32",X"32",X"32",X"2C",X"08",X"07",X"08",X"2C",X"2C",X"2C",X"2C",X"2C",X"32",X"33",X"57",X"5D",X"82",X"88",X"82",X"82",X"2C",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"2C",X"2C",X"08",X"2C",X"2C",X"2C",X"08",X"32",X"33",X"57",X"33",X"32",X"2C",X"2C",X"2C",X"2C",X"08",X"08",X"32",X"33",X"57",X"57",X"33",X"32",X"32",X"57",X"5D",X"33",X"33",X"33",X"33",X"32",X"2C",X"08",X"08",X"2C",X"2C",X"2C",X"2C",X"32",X"33",X"57",X"5D",X"82",X"88",X"88",X"82",X"2C",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"2C",X"08",X"2C",X"2C",X"2C",X"32",X"33",X"33",X"33",X"32",X"32",X"33",X"57",X"33",X"32",X"32",X"32",X"57",X"5D",X"5D",X"82",X"88",X"5E",X"5D",X"5D",X"5E",X"33",X"32",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"32",X"33",X"33",X"57",X"5D",X"88",X"88",X"82",X"81",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"2C",X"08",X"2C",X"2C",X"32",X"33",X"33",X"32",X"2C",X"32",X"32",X"33",X"5E",X"5D",X"57",X"57",X"57",X"5D",X"82",X"82",X"88",X"88",X"82",X"5E",X"5D",X"57",X"33",X"32",X"32",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"33",X"33",X"57",X"5D",X"82",X"88",X"AC",X"AD",X"56",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"2C",X"2C",X"32",X"32",X"33",X"33",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"57",X"5D",X"5D",X"5D",X"82",X"5E",X"5D",X"5D",X"57",X"33",X"33",X"33",X"33",X"33",X"32",X"32",X"2C",X"32",X"32",X"32",X"2C",X"32",X"32",X"32",X"32",X"33",X"33",X"57",X"5D",X"82",X"AC",X"AC",X"B3",X"81",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"32",X"32",X"32",X"33",X"57",X"33",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"57",X"5D",X"5D",X"5D",X"5D",X"57",X"33",X"33",X"32",X"32",X"33",X"33",X"33",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"57",X"5D",X"82",X"88",X"AC",X"AC",X"56",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"01",X"2C",X"32",X"32",X"33",X"57",X"57",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"57",X"57",X"5D",X"5D",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"33",X"33",X"32",X"32",X"33",X"33",X"33",X"33",X"33",X"32",X"33",X"33",X"33",X"33",X"57",X"5E",X"88",X"AD",X"81",X"01",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"01",X"32",X"33",X"32",X"33",X"57",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"2C",X"07",X"2B",X"2C",X"2C",X"07",X"2C",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"33",X"33",X"32",X"33",X"57",X"57",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"57",X"5E",X"88",X"AC",X"5D",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"33",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"2C",X"07",X"07",X"07",X"07",X"08",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"32",X"32",X"32",X"57",X"33",X"57",X"57",X"33",X"33",X"33",X"33",X"33",X"33",X"33",X"57",X"5E",X"88",X"88",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"57",X"5D",X"5D",X"5D",X"57",X"57",X"33",X"33",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"33",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"57",X"57",X"57",X"33",X"32",X"33",X"33",X"57",X"33",X"33",X"5D",X"5E",X"88",X"88",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"32",X"33",X"32",X"2C",X"32",X"32",X"32",X"5D",X"82",X"88",X"B3",X"88",X"5D",X"57",X"57",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"5D",X"82",X"88",X"AD",X"AD",X"88",X"82",X"5D",X"33",X"33",X"32",X"2C",X"32",X"33",X"57",X"33",X"33",X"5D",X"82",X"82",X"57",X"01",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"32",X"33",X"32",X"2C",X"2C",X"32",X"32",X"32",X"57",X"5D",X"B3",X"AD",X"32",X"07",X"2C",X"2C",X"2C",X"56",X"32",X"2C",X"32",X"32",X"2C",X"2C",X"32",X"5D",X"82",X"88",X"88",X"82",X"5D",X"33",X"32",X"32",X"32",X"08",X"2C",X"33",X"57",X"57",X"33",X"57",X"5D",X"82",X"5D",X"2B",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"56",X"33",X"32",X"2C",X"2C",X"2C",X"32",X"2C",X"32",X"32",X"5D",X"88",X"57",X"2C",X"2C",X"07",X"01",X"2B",X"07",X"01",X"2B",X"2C",X"32",X"57",X"33",X"5D",X"5E",X"5D",X"5D",X"33",X"32",X"32",X"32",X"32",X"2C",X"08",X"2C",X"33",X"57",X"33",X"57",X"5D",X"5D",X"56",X"07",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"57",X"33",X"33",X"32",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"5D",X"5D",X"5D",X"32",X"2C",X"2B",X"2B",X"2B",X"2C",X"2C",X"32",X"5D",X"5D",X"5D",X"5D",X"39",X"33",X"33",X"33",X"33",X"33",X"33",X"2C",X"08",X"08",X"33",X"57",X"57",X"33",X"57",X"82",X"5D",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"57",X"33",X"32",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"32",X"33",X"39",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"33",X"32",X"32",X"33",X"33",X"57",X"32",X"2C",X"08",X"2C",X"33",X"5D",X"33",X"33",X"5D",X"82",X"57",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"5D",X"57",X"33",X"32",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"0E",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"32",X"33",X"57",X"33",X"2C",X"2C",X"2C",X"32",X"5D",X"5D",X"33",X"57",X"5E",X"82",X"2C",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"5D",X"5D",X"33",X"57",X"32",X"2C",X"2C",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"33",X"32",X"2C",X"2C",X"2C",X"57",X"5D",X"33",X"57",X"5D",X"82",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"81",X"57",X"57",X"57",X"2C",X"2C",X"32",X"32",X"32",X"32",X"32",X"2C",X"32",X"32",X"2C",X"32",X"32",X"32",X"32",X"32",X"32",X"2C",X"32",X"32",X"32",X"32",X"33",X"33",X"32",X"32",X"32",X"2C",X"32",X"5D",X"57",X"33",X"57",X"81",X"5D",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"82",X"57",X"57",X"33",X"2C",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"2C",X"2C",X"32",X"32",X"32",X"32",X"33",X"33",X"32",X"32",X"32",X"32",X"32",X"57",X"5D",X"57",X"57",X"57",X"57",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"81",X"81",X"57",X"57",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"33",X"32",X"32",X"32",X"33",X"33",X"32",X"57",X"5D",X"5D",X"57",X"57",X"82",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"5D",X"57",X"32",X"32",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"33",X"57",X"57",X"5D",X"5D",X"57",X"57",X"5D",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"56",X"57",X"57",X"32",X"32",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"2C",X"2B",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"32",X"32",X"33",X"33",X"33",X"57",X"57",X"5D",X"5D",X"5D",X"82",X"81",X"2C",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"57",X"57",X"33",X"32",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"2B",X"07",X"07",X"2C",X"2C",X"32",X"32",X"32",X"32",X"33",X"33",X"57",X"57",X"57",X"5D",X"82",X"82",X"82",X"AC",X"AD",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"57",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"2C",X"07",X"07",X"2B",X"07",X"08",X"2C",X"2C",X"32",X"32",X"33",X"57",X"57",X"57",X"57",X"5D",X"82",X"82",X"82",X"AC",X"D7",X"AC",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"57",X"32",X"32",X"32",X"2C",X"2C",X"08",X"08",X"07",X"07",X"2C",X"07",X"08",X"2C",X"2C",X"2C",X"32",X"33",X"57",X"57",X"5D",X"81",X"82",X"82",X"82",X"AC",X"D7",X"AC",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"81",X"57",X"32",X"32",X"2C",X"2C",X"2C",X"08",X"08",X"2C",X"08",X"08",X"2C",X"2C",X"2C",X"32",X"33",X"57",X"57",X"5D",X"82",X"82",X"88",X"88",X"AD",X"D7",X"81",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"81",X"5D",X"32",X"32",X"32",X"32",X"2C",X"2C",X"2C",X"2C",X"32",X"32",X"32",X"32",X"57",X"57",X"5D",X"81",X"82",X"88",X"88",X"AC",X"B3",X"D7",X"81",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"81",X"88",X"5D",X"57",X"57",X"57",X"57",X"57",X"57",X"57",X"57",X"57",X"5D",X"81",X"82",X"82",X"88",X"AC",X"AC",X"AD",X"D7",X"AC",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"82",X"D7",X"AC",X"82",X"82",X"82",X"82",X"88",X"88",X"88",X"AC",X"AC",X"AC",X"AC",X"AC",X"AC",X"AD",X"D7",X"AC",X"57",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"81",X"AD",X"AD",X"AD",X"AD",X"AD",X"AD",X"AD",X"AD",X"AD",X"AD",X"AD",X"AD",X"AD",X"AD",X"AC",X"57",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00"
);

constant C1 : Array3 :=(
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"88",X"88",X"88",X"88",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"57",X"88",X"88",X"88",X"89",X"89",X"89",X"88",X"88",X"88",X"88",X"57",X"32",X"01",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5E",X"89",X"89",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"88",X"89",X"88",X"57",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"89",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"B3",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"2B",X"00",X"00",X"00",X"5D",X"89",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"57",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"B3",X"56",X"00",X"00",X"57",X"89",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"88",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"B3",X"5D",X"00",X"2B",X"89",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"89",X"5D",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"89",X"88",X"2B",X"57",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"89",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"82",X"88",X"82",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"B3",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"89",X"57",X"5D",X"82",X"5E",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"89",X"89",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"89",X"88",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"88",X"AD",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"2B",X"88",X"89",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"88",X"B3",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"82",X"88",X"AD",X"89",X"89",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"82",X"B3",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"82",X"B3",X"89",X"88",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"88",X"B3",X"2B",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"89",X"B3",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"89",X"89",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"B3",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"89",X"82",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"56",X"B3",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"B3",X"56",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2B",X"B3",X"88",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"B3",X"2B",X"00",X"00",
X"00",X"00",X"00",X"00",X"88",X"89",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"89",X"81",X"00",X"00",
X"00",X"00",X"00",X"82",X"B3",X"82",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"AD",X"2B",X"00",
X"00",X"00",X"00",X"B3",X"82",X"82",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"88",X"5E",X"5D",X"89",X"5D",X"00",
X"00",X"00",X"00",X"B3",X"89",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"88",X"5E",X"B3",X"56",X"00",
X"00",X"00",X"00",X"00",X"88",X"89",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"82",X"88",X"5D",X"5D",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"88",X"88",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"89",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"88",X"82",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"89",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"AD",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"88",X"88",X"5E",X"5E",X"88",X"82",X"5D",X"5D",X"82",X"32",X"08",X"32",X"32",X"32",X"33",X"33",X"33",X"33",X"33",X"33",X"57",X"5D",X"5D",X"5D",X"5E",X"5E",X"82",X"82",X"88",X"88",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"82",X"89",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"AD",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"82",X"AD",X"88",X"82",X"82",X"82",X"82",X"82",X"89",X"88",X"B3",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"88",X"82",X"88",X"5E",X"5D",X"B3",X"5D",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"B3",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"89",X"33",X"08",X"08",X"5D",X"AD",X"32",X"08",X"57",X"5E",X"5E",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"89",X"89",X"5E",X"5E",X"88",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"AD",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"AD",X"82",X"08",X"08",X"08",X"08",X"33",X"B3",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"89",X"5D",X"5D",X"B3",X"56",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"89",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5D",X"82",X"B3",X"5D",X"08",X"08",X"08",X"08",X"08",X"5D",X"88",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"32",X"89",X"5D",X"2B",X"82",X"2B",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"88",X"82",X"82",X"82",X"82",X"82",X"5D",X"82",X"B3",X"39",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"82",X"89",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"88",X"82",X"82",X"82",X"82",X"5E",X"5E",X"AD",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"82",X"88",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"5D",X"B3",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"88",X"82",X"82",X"82",X"82",X"82",X"89",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"D7",X"D7",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"89",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"89",X"82",X"82",X"82",X"82",X"88",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"88",X"B3",X"32",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"B3",X"B3",X"88",X"07",X"08",X"08",X"08",X"08",X"08",X"5D",X"89",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"AD",X"82",X"82",X"82",X"82",X"AD",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"B3",X"D7",X"88",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"AD",X"D7",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"89",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"B3",X"82",X"82",X"AD",X"88",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"AD",X"B3",X"B3",X"2C",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"32",X"88",X"33",X"07",X"08",X"08",X"08",X"08",X"08",X"89",X"89",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"B3",X"82",X"88",X"B3",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"D7",X"88",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"88",X"B3",X"88",X"88",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"33",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"01",X"88",X"B3",X"81",X"5D",X"89",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"2B",X"2B",X"B3",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"89",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"81",X"89",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"57",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"82",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"82",X"89",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"89",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"B3",X"B3",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"AD",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"88",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"32",X"81",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"88",X"0F",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"AD",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"88",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"89",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"88",X"88",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"88",X"82",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"82",X"64",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"88",X"0D",X"5C",X"B3",X"33",X"08",X"08",X"08",X"08",X"82",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"0D",X"88",X"5D",X"88",X"5E",X"5D",X"5D",X"88",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"AD",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"0D",X"5D",X"0D",X"31",X"B3",X"5E",X"5E",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"AD",X"64",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"88",X"5D",X"0D",X"38",X"89",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"2C",X"5E",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"82",X"89",X"0F",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"88",X"88",X"88",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"89",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"89",X"65",X"0F",X"08",X"08",X"08",X"08",X"08",X"08",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"89",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"88",X"89",X"3A",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"89",X"89",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"82",X"5E",X"64",X"89",X"39",X"33",X"33",X"33",X"33",X"89",X"89",X"89",X"89",X"89",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"24",X"56",X"89",X"89",X"89",X"89",X"89",X"89",X"89",X"56",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00"
);

constant C2 : Array3 :=(
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"2B",X"2B",X"2B",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"57",X"5D",X"82",X"88",X"88",X"88",X"88",X"88",X"89",X"89",X"57",X"32",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"89",X"89",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"88",X"88",X"88",X"5D",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"89",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"89",X"89",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"56",X"00",X"00",X"00",X"57",X"89",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"82",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"82",X"00",X"00",X"32",X"89",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"82",X"57",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"01",X"88",X"88",X"00",X"00",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"89",X"88",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"89",X"89",X"89",X"89",X"89",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"82",X"89",X"88",X"07",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"00",X"2B",X"89",X"5E",X"88",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"89",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"5E",X"89",X"88",X"5E",X"88",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"B3",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"88",X"89",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"B3",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"32",X"56",X"89",X"AD",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"B3",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"88",X"89",X"AD",X"B3",X"89",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"B3",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"B3",X"89",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"B3",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"B3",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"AD",X"01",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"88",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"89",X"88",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"B3",X"5D",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"82",X"B3",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"B3",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"57",X"B3",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"82",X"00",X"00",X"00",
X"00",X"00",X"00",X"2C",X"B3",X"82",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"2B",X"00",X"00",
X"00",X"00",X"00",X"5D",X"B3",X"82",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"2B",X"00",X"00",
X"00",X"00",X"00",X"00",X"82",X"B3",X"88",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"89",X"82",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"56",X"89",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"82",X"32",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"07",X"AD",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"88",X"88",X"89",X"89",X"89",X"89",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"89",X"89",X"89",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"B3",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"88",X"89",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"82",X"5E",X"5D",X"82",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"89",X"88",X"88",X"88",X"88",X"88",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"82",X"89",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2B",X"B3",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"89",X"88",X"82",X"5E",X"88",X"88",X"88",X"82",X"AD",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"88",X"5E",X"82",X"5E",X"5D",X"B3",X"56",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"5D",X"B3",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"82",X"AD",X"82",X"32",X"08",X"5D",X"89",X"5D",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"89",X"89",X"5E",X"5E",X"88",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"82",X"89",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"88",X"89",X"08",X"08",X"08",X"08",X"32",X"B3",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"AD",X"5D",X"5D",X"B3",X"56",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"88",X"88",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"88",X"89",X"08",X"08",X"08",X"08",X"08",X"32",X"89",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"32",X"89",X"5D",X"2B",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"89",X"88",X"82",X"82",X"82",X"82",X"5E",X"5E",X"89",X"89",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"07",X"08",X"08",X"08",X"08",X"08",X"07",X"5E",X"89",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"89",X"88",X"82",X"82",X"82",X"82",X"5E",X"88",X"89",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"33",X"88",X"32",X"07",X"08",X"08",X"08",X"08",X"08",X"5D",X"B3",X"01",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"07",X"89",X"88",X"82",X"82",X"82",X"82",X"88",X"89",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"89",X"D7",X"88",X"07",X"08",X"08",X"08",X"08",X"08",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"88",X"88",X"82",X"82",X"82",X"82",X"AD",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"82",X"B3",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"89",X"B3",X"B3",X"08",X"07",X"08",X"08",X"08",X"08",X"5D",X"2C",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"82",X"88",X"82",X"82",X"82",X"82",X"89",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"AD",X"D7",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"D7",X"B3",X"08",X"07",X"08",X"08",X"08",X"08",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"5D",X"89",X"82",X"82",X"82",X"82",X"AD",X"39",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"89",X"B3",X"AD",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"5E",X"57",X"07",X"08",X"08",X"08",X"08",X"08",X"5D",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"56",X"B3",X"82",X"82",X"82",X"88",X"88",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"D7",X"89",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"89",X"B3",X"88",X"88",X"88",X"82",X"89",X"0F",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"57",X"32",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"82",X"B3",X"56",X"5D",X"88",X"AD",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"2C",X"5D",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"00",X"56",X"B3",X"88",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"B3",X"88",X"5D",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"81",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"89",X"88",X"89",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"5D",X"64",X"3A",X"65",X"88",X"88",X"5E",X"5D",X"32",X"32",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"B3",X"88",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"65",X"0F",X"0F",X"15",X"3A",X"64",X"64",X"64",X"88",X"88",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"5D",X"5E",X"5E",X"82",X"88",X"89",X"2C",X"08",X"5E",X"24",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"89",X"B3",X"88",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"64",X"0F",X"39",X"39",X"15",X"0F",X"0F",X"0F",X"3A",X"2C",X"2B",X"2B",X"2B",X"32",X"32",X"56",X"56",X"56",X"5E",X"65",X"64",X"64",X"64",X"3A",X"89",X"2C",X"33",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"89",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"64",X"0F",X"39",X"39",X"39",X"39",X"39",X"39",X"3A",X"0E",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"0F",X"15",X"0F",X"0F",X"0F",X"3A",X"88",X"07",X"5E",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"89",X"33",X"08",X"08",X"08",X"08",X"08",X"5E",X"64",X"0F",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"3A",X"0F",X"07",X"01",X"01",X"01",X"07",X"08",X"3A",X"3A",X"39",X"39",X"39",X"0F",X"65",X"5D",X"08",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"89",X"08",X"08",X"08",X"08",X"08",X"5E",X"65",X"0F",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"3A",X"3A",X"3A",X"3A",X"3A",X"3A",X"3A",X"3A",X"39",X"39",X"39",X"39",X"0F",X"89",X"33",X"5E",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"81",X"5E",X"08",X"08",X"08",X"08",X"57",X"64",X"0F",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"3A",X"3A",X"3A",X"3A",X"3A",X"39",X"39",X"39",X"39",X"39",X"0F",X"3A",X"5E",X"5D",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"89",X"3A",X"08",X"08",X"08",X"32",X"89",X"0F",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"0F",X"64",X"88",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"AD",X"39",X"08",X"08",X"08",X"88",X"64",X"0F",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"0F",X"3A",X"B3",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"AD",X"5E",X"08",X"08",X"32",X"B3",X"16",X"0F",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"0F",X"15",X"B3",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"89",X"64",X"08",X"08",X"57",X"8F",X"3A",X"0F",X"0F",X"15",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"39",X"0F",X"0F",X"3A",X"B3",X"81",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"81",X"89",X"3A",X"08",X"32",X"88",X"89",X"64",X"3A",X"0F",X"0F",X"0F",X"0F",X"15",X"0F",X"0F",X"0F",X"0F",X"0F",X"3A",X"89",X"89",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"88",X"89",X"33",X"08",X"33",X"5D",X"88",X"88",X"64",X"64",X"5E",X"3A",X"3A",X"3A",X"5E",X"65",X"8F",X"B3",X"81",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"81",X"88",X"5E",X"39",X"5D",X"5E",X"5E",X"88",X"88",X"88",X"89",X"B3",X"B3",X"AC",X"81",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"56",X"5D",X"5D",X"57",X"57",X"57",X"57",X"57",X"56",X"32",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00"
);

constant B1: Array2 :=(
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"2C",X"56",X"5D",X"81",X"88",X"AD",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"89",X"88",X"82",X"5D",X"56",X"32",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"88",X"B3",X"B3",X"B3",X"B3",X"B3",X"89",X"82",X"5E",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"89",X"89",X"AD",X"B3",X"B3",X"B3",X"AD",X"89",X"82",X"57",X"2C",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"B3",X"AD",X"B3",X"5E",X"2D",X"89",X"89",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"57",X"57",X"58",X"5E",X"82",X"82",X"88",X"AD",X"B3",X"89",X"82",X"56",X"07",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"B3",X"2D",X"82",X"89",X"26",X"2D",X"B3",X"5E",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"57",X"57",X"57",X"57",X"57",X"82",X"82",X"AD",X"B3",X"AD",X"82",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"D7",X"2D",X"2D",X"B3",X"5E",X"02",X"57",X"B3",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"57",X"57",X"82",X"82",X"AD",X"B3",X"88",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"B3",X"89",X"02",X"58",X"B3",X"57",X"26",X"58",X"B3",X"33",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"57",X"58",X"82",X"B3",X"B3",X"82",X"01",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"58",X"02",X"5E",X"B3",X"2D",X"27",X"5E",X"AD",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"AD",X"B3",X"B3",X"2B",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"B3",X"2D",X"27",X"82",X"AD",X"2D",X"2D",X"82",X"AD",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"AC",X"B3",X"B3",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"B3",X"2D",X"2D",X"89",X"89",X"2D",X"2D",X"82",X"89",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"AC",X"B3",X"89",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"B3",X"2D",X"2D",X"89",X"88",X"2D",X"2D",X"88",X"89",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"AD",X"B3",X"32",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"B3",X"2D",X"2D",X"89",X"82",X"2D",X"2D",X"88",X"89",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"AC",X"B3",X"5D",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"B3",X"2D",X"2D",X"89",X"82",X"2D",X"2D",X"88",X"89",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"5E",X"AC",X"B3",X"5D",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"B3",X"2D",X"2D",X"AD",X"82",X"2D",X"2D",X"88",X"89",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"AC",X"B3",X"32",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"B3",X"2D",X"2D",X"89",X"82",X"2D",X"2D",X"82",X"89",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"B3",X"89",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"57",X"B3",X"2D",X"2D",X"89",X"89",X"2D",X"2D",X"82",X"AD",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"AD",X"B3",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"B3",X"2D",X"2D",X"89",X"89",X"2D",X"2D",X"82",X"B3",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"58",X"82",X"B3",X"B3",X"2C",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"B3",X"33",X"27",X"82",X"AD",X"2D",X"2D",X"5E",X"B3",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"57",X"82",X"AD",X"B3",X"88",X"2B",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"58",X"02",X"5E",X"B3",X"2D",X"27",X"58",X"B3",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"57",X"57",X"82",X"89",X"B3",X"AD",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"B3",X"89",X"02",X"57",X"B3",X"58",X"26",X"57",X"B3",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"57",X"57",X"5E",X"82",X"AD",X"B3",X"89",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"D7",X"58",X"02",X"89",X"89",X"26",X"2D",X"B3",X"5E",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"57",X"57",X"58",X"82",X"89",X"B3",X"B3",X"AD",X"81",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"81",X"D7",X"82",X"82",X"B3",X"57",X"02",X"89",X"89",X"27",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"5E",X"82",X"88",X"AD",X"B3",X"B3",X"B3",X"88",X"5D",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"B3",X"B3",X"B3",X"B3",X"89",X"B3",X"B3",X"83",X"5E",X"5E",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"89",X"AD",X"B3",X"B3",X"B3",X"89",X"88",X"5D",X"32",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"2C",X"56",X"5D",X"82",X"82",X"89",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"B3",X"AD",X"89",X"88",X"88",X"82",X"5D",X"56",X"2C",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00"
); 
constant lives : Array5 :=(
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"2C",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5D",X"82",X"88",X"88",X"88",X"88",X"82",X"57",X"2C",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"00",X"2B",X"88",X"89",X"5E",X"5E",X"5E",X"5E",X"5E",X"82",X"89",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"82",X"2B",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5D",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"88",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"89",X"57",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"89",X"5E",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"5D",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"56",X"81",X"82",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"82",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"82",X"B3",X"88",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"5D",X"00",X"00",
X"00",X"00",X"00",X"5D",X"AD",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"89",X"56",X"00",
X"00",X"00",X"00",X"89",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"00",
X"00",X"00",X"88",X"89",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"82",X"89",X"00",
X"00",X"00",X"00",X"88",X"88",X"82",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"88",X"88",X"88",X"82",X"82",X"82",X"82",X"82",X"82",X"5E",X"5E",X"5E",X"5E",X"88",X"5D",X"00",
X"00",X"00",X"00",X"82",X"88",X"5E",X"5E",X"5E",X"5E",X"88",X"82",X"5E",X"88",X"88",X"5D",X"57",X"5D",X"5D",X"5D",X"5D",X"5E",X"5E",X"5E",X"5E",X"88",X"5E",X"5E",X"89",X"2B",X"00",
X"00",X"00",X"00",X"89",X"82",X"5E",X"5E",X"82",X"88",X"5D",X"5D",X"88",X"5D",X"5E",X"2C",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"33",X"88",X"89",X"5D",X"00",X"00",
X"00",X"00",X"00",X"89",X"82",X"5E",X"82",X"88",X"32",X"08",X"32",X"5D",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"07",X"08",X"82",X"82",X"2B",X"00",X"00",
X"00",X"00",X"00",X"88",X"82",X"82",X"88",X"0E",X"08",X"08",X"08",X"07",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"07",X"32",X"33",X"08",X"08",X"07",X"5E",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"88",X"82",X"88",X"33",X"08",X"08",X"08",X"07",X"08",X"5D",X"32",X"07",X"08",X"08",X"08",X"08",X"08",X"57",X"D7",X"2C",X"07",X"08",X"5E",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"89",X"88",X"88",X"0F",X"08",X"08",X"08",X"07",X"08",X"D7",X"5D",X"08",X"08",X"08",X"08",X"08",X"07",X"2C",X"88",X"2C",X"07",X"08",X"5E",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"B3",X"AD",X"88",X"33",X"08",X"08",X"08",X"08",X"07",X"5D",X"33",X"07",X"08",X"08",X"08",X"08",X"08",X"07",X"07",X"08",X"08",X"08",X"5E",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"88",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"07",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"B3",X"0F",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"5E",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"5E",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"5E",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"5E",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"5E",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"5E",X"33",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"08",X"5E",X"5E",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"5E",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00"
);
    
constant BUN : Array7 :=(
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"5D",X"57",X"07",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"B3",X"D7",X"D7",X"B3",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"D7",X"AC",X"AC",X"AC",X"B3",X"D7",X"56",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"81",X"D7",X"82",X"57",X"2D",X"57",X"82",X"AD",X"B3",X"2B",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2B",X"B3",X"AC",X"51",X"2D",X"2D",X"2D",X"57",X"AC",X"B3",X"88",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"88",X"B3",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"AC",X"B3",X"56",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"B3",X"AC",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"B3",X"88",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"5D",X"B3",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"AC",X"B3",X"2C",X"00",X"00",X"00",
X"00",X"00",X"00",X"88",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"5D",X"00",X"00",X"00",
X"00",X"00",X"2C",X"B3",X"88",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"89",X"00",X"00",X"00",
X"00",X"00",X"5D",X"B3",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"B3",X"32",X"00",X"00",
X"00",X"00",X"88",X"B3",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"5D",X"00",X"00",
X"00",X"00",X"89",X"AD",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"88",X"00",X"00",
X"00",X"2B",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"AD",X"00",X"00",
X"00",X"56",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"2B",X"00",
X"00",X"5D",X"B3",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"B3",X"56",X"00",
X"00",X"82",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"5D",X"00",
X"00",X"88",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"82",X"00",
X"00",X"88",X"89",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"89",X"88",X"00",
X"00",X"89",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"89",X"00",
X"00",X"89",X"5E",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"5E",X"AD",X"00",
X"00",X"AD",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"AD",X"00",
X"00",X"AD",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"01",
X"00",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"2B",
X"00",X"89",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"2B",
X"00",X"89",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"AD",X"2B",
X"00",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"89",X"2B",
X"00",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"89",X"2B",
X"00",X"89",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"89",X"07",
X"00",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"89",X"00",
X"00",X"89",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"89",X"00",
X"00",X"89",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"89",X"00",
X"00",X"88",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"89",X"00",
X"00",X"88",X"83",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"00",
X"00",X"81",X"B3",X"89",X"82",X"5E",X"58",X"58",X"58",X"57",X"58",X"58",X"58",X"5E",X"82",X"82",X"89",X"B3",X"AD",X"00",
X"00",X"5D",X"89",X"58",X"89",X"89",X"89",X"89",X"89",X"89",X"89",X"89",X"89",X"89",X"89",X"88",X"5E",X"5E",X"88",X"00",
X"00",X"56",X"AD",X"2D",X"02",X"26",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"27",X"02",X"02",X"82",X"88",X"00",
X"00",X"2B",X"B3",X"AD",X"88",X"5E",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"33",X"58",X"82",X"89",X"B3",X"5D",X"00",
X"00",X"00",X"B3",X"83",X"5E",X"AD",X"AD",X"AD",X"89",X"89",X"89",X"89",X"89",X"89",X"AD",X"89",X"5E",X"AD",X"5D",X"00",
X"00",X"00",X"56",X"B3",X"2D",X"02",X"2D",X"33",X"57",X"58",X"58",X"58",X"57",X"33",X"2D",X"02",X"58",X"B3",X"2B",X"00",
X"00",X"00",X"00",X"5D",X"B3",X"83",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"83",X"B3",X"32",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"88",X"89",X"AD",X"89",X"89",X"89",X"89",X"89",X"89",X"88",X"81",X"07",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00"
);
  
constant box : Array8 :=(
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"5D",X"82",X"5D",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"82",X"82",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"07",X"5D",X"82",X"5D",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"B3",X"D7",X"D7",X"D7",X"B3",X"57",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"81",X"D7",X"D7",X"D7",X"D7",X"88",X"01",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"D7",X"D7",X"D7",X"B3",X"57",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"D7",X"AC",X"AC",X"AC",X"B3",X"D7",X"56",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5D",X"D7",X"AD",X"AC",X"AC",X"AD",X"D7",X"88",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"B3",X"D7",X"AC",X"82",X"AC",X"B3",X"D7",X"32",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"D7",X"AC",X"57",X"57",X"57",X"82",X"B3",X"B3",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2C",X"B3",X"AD",X"AC",X"57",X"57",X"82",X"AC",X"D7",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"D7",X"AC",X"5E",X"2D",X"57",X"82",X"B3",X"B3",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"32",X"B3",X"AC",X"57",X"57",X"2D",X"2D",X"57",X"AC",X"B3",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"89",X"B3",X"AC",X"57",X"2D",X"2D",X"57",X"82",X"AD",X"B3",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"D7",X"AC",X"57",X"2D",X"2D",X"2D",X"57",X"AC",X"B3",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"89",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"B3",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"32",X"B3",X"AC",X"82",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"B3",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"89",X"B3",X"AC",X"57",X"2D",X"2D",X"2D",X"2D",X"82",X"AD",X"B3",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"2C",X"B3",X"AC",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"82",X"00",X"00",X"00",X"00",X"00",X"00",X"88",X"B3",X"AC",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AC",X"B3",X"2B",X"00",X"00",X"00",X"00",X"00",X"2C",X"B3",X"AC",X"57",X"2D",X"2D",X"2D",X"2D",X"57",X"57",X"AC",X"B3",X"82",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"82",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"AD",X"B3",X"01",X"00",X"00",X"00",X"00",X"2B",X"B3",X"AD",X"5E",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"5D",X"00",X"00",X"00",X"00",X"00",X"5E",X"B3",X"AC",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"AD",X"B3",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"AD",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"B3",X"56",X"00",X"00",X"00",X"00",X"57",X"B3",X"AC",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"AD",X"89",X"00",X"00",X"00",X"00",X"00",X"89",X"AD",X"58",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"B3",X"56",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"2C",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"B3",X"88",X"00",X"00",X"00",X"00",X"88",X"B3",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"B3",X"2B",X"00",X"00",X"00",X"2C",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"B3",X"88",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"5D",X"B3",X"58",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"AD",X"00",X"00",X"00",X"01",X"AD",X"AD",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"5D",X"00",X"00",X"00",X"5D",X"B3",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"88",X"AD",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"88",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"B3",X"32",X"00",X"00",X"32",X"B3",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"88",X"00",X"00",X"00",X"88",X"AD",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"B3",X"32",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"AD",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"57",X"B3",X"5D",X"00",X"00",X"5D",X"B3",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"88",X"AD",X"00",X"00",X"00",X"AD",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"B3",X"5D",X"00",X"00",X"00",X"00",
X"00",X"00",X"2B",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"88",X"00",X"00",X"82",X"B3",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"B3",X"2C",X"00",X"2B",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"88",X"00",X"00",X"00",X"00",
X"00",X"00",X"56",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"89",X"00",X"00",X"88",X"AD",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"56",X"00",X"56",X"B3",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"88",X"89",X"00",X"00",X"00",X"00",
X"00",X"00",X"5D",X"B3",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"07",X"00",X"AD",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"AD",X"5D",X"00",X"5D",X"B3",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"2B",X"00",X"00",X"00",
X"00",X"00",X"82",X"AD",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"2B",X"00",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"89",X"88",X"00",X"81",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"B3",X"32",X"00",X"00",X"00",
X"00",X"00",X"88",X"AD",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"B3",X"32",X"2B",X"B3",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"88",X"00",X"82",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"B3",X"57",X"00",X"00",X"00",
X"00",X"00",X"88",X"89",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"AD",X"56",X"2C",X"B3",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"89",X"2B",X"88",X"89",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"AD",X"5D",X"00",X"00",X"00",
X"00",X"00",X"AD",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"89",X"5D",X"56",X"B3",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"5E",X"89",X"32",X"88",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"89",X"82",X"00",X"00",X"00",
X"00",X"00",X"AD",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"5D",X"5D",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"89",X"57",X"88",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"89",X"88",X"00",X"00",X"00",
X"00",X"00",X"AD",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"82",X"5D",X"89",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"89",X"5D",X"88",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"88",X"00",X"00",X"00",
X"00",X"00",X"AD",X"5E",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"5E",X"88",X"88",X"89",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"89",X"88",X"88",X"5E",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"89",X"00",X"00",X"00",
X"00",X"00",X"AD",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"88",X"88",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"88",X"88",X"88",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"5E",X"89",X"00",X"00",X"00",
X"00",X"00",X"B3",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"88",X"88",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"51",X"82",X"AD",X"88",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"AD",X"00",X"00",X"00",
X"00",X"00",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"88",X"AD",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"88",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"AD",X"00",X"00",X"00",
X"00",X"00",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"88",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"88",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"00",X"00",X"00",
X"00",X"00",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"88",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"B3",X"88",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"00",X"00",X"00",
X"00",X"00",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"88",X"AD",X"82",X"51",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"5E",X"B3",X"88",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"AD",X"00",X"00",X"00",
X"00",X"00",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"88",X"89",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"AD",X"88",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"89",X"00",X"00",X"00",
X"00",X"00",X"AD",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"88",X"88",X"82",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"88",X"88",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"89",X"00",X"00",X"00",
X"00",X"00",X"AD",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"88",X"83",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"82",X"88",X"82",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"89",X"00",X"00",X"00",
X"00",X"00",X"89",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"82",X"5D",X"89",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"89",X"81",X"82",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"58",X"89",X"00",X"00",X"00",
X"00",X"00",X"88",X"58",X"26",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"02",X"58",X"82",X"56",X"89",X"27",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"02",X"89",X"5C",X"82",X"58",X"26",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"02",X"58",X"89",X"00",X"00",X"00",
X"00",X"00",X"88",X"AD",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"33",X"58",X"AD",X"5D",X"2B",X"B3",X"82",X"57",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"57",X"82",X"B3",X"2B",X"5D",X"AD",X"58",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"2D",X"33",X"58",X"AD",X"88",X"00",X"00",X"00",
X"00",X"00",X"5D",X"B3",X"89",X"AD",X"89",X"89",X"89",X"89",X"88",X"89",X"89",X"89",X"89",X"89",X"AD",X"89",X"B3",X"5D",X"00",X"B3",X"AD",X"AD",X"89",X"89",X"89",X"89",X"89",X"88",X"89",X"89",X"89",X"89",X"89",X"AD",X"89",X"B3",X"07",X"57",X"B3",X"89",X"89",X"89",X"89",X"89",X"89",X"88",X"89",X"89",X"89",X"89",X"89",X"AD",X"89",X"B3",X"82",X"00",X"00",X"00",
X"00",X"00",X"5D",X"89",X"02",X"57",X"5E",X"82",X"82",X"82",X"82",X"82",X"82",X"82",X"5E",X"58",X"57",X"02",X"5F",X"5D",X"00",X"89",X"2D",X"2D",X"58",X"5E",X"82",X"82",X"82",X"82",X"82",X"82",X"82",X"5E",X"58",X"2D",X"2D",X"89",X"00",X"56",X"89",X"02",X"57",X"5E",X"82",X"82",X"82",X"82",X"82",X"82",X"82",X"5E",X"58",X"57",X"02",X"5F",X"81",X"00",X"00",X"00",
X"00",X"00",X"56",X"B3",X"58",X"2D",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"2D",X"57",X"B3",X"56",X"00",X"88",X"89",X"2D",X"27",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"26",X"2D",X"82",X"AD",X"00",X"32",X"B3",X"58",X"2D",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"02",X"2D",X"57",X"B3",X"5D",X"00",X"00",X"00",
X"00",X"00",X"2B",X"B3",X"AD",X"89",X"89",X"82",X"82",X"5E",X"58",X"58",X"58",X"5E",X"82",X"88",X"AD",X"89",X"B3",X"32",X"00",X"82",X"B3",X"89",X"89",X"88",X"82",X"5E",X"5E",X"58",X"58",X"5E",X"82",X"82",X"89",X"AD",X"B3",X"88",X"00",X"2B",X"B3",X"AD",X"89",X"89",X"82",X"82",X"5E",X"58",X"58",X"58",X"5E",X"82",X"88",X"AD",X"AD",X"B3",X"32",X"00",X"00",X"00",
X"00",X"00",X"00",X"88",X"83",X"2D",X"82",X"88",X"89",X"89",X"89",X"89",X"89",X"89",X"89",X"88",X"58",X"57",X"B3",X"2B",X"00",X"32",X"B3",X"33",X"58",X"88",X"89",X"89",X"89",X"89",X"89",X"89",X"89",X"89",X"82",X"2D",X"89",X"82",X"00",X"00",X"88",X"83",X"2D",X"82",X"89",X"89",X"89",X"89",X"89",X"89",X"89",X"88",X"88",X"58",X"33",X"B3",X"2B",X"00",X"00",X"00",
X"00",X"00",X"00",X"07",X"B3",X"5E",X"02",X"02",X"26",X"2D",X"2D",X"2D",X"2D",X"27",X"02",X"02",X"27",X"B3",X"82",X"00",X"00",X"00",X"5D",X"B3",X"2D",X"02",X"02",X"27",X"2D",X"2D",X"2D",X"2D",X"26",X"02",X"02",X"58",X"B3",X"2B",X"00",X"00",X"07",X"B3",X"5E",X"02",X"02",X"26",X"2D",X"2D",X"2D",X"2D",X"26",X"02",X"02",X"27",X"B3",X"82",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"2B",X"5D",X"AC",X"AD",X"83",X"82",X"5E",X"58",X"5E",X"82",X"5E",X"83",X"89",X"AD",X"88",X"00",X"00",X"00",X"00",X"56",X"81",X"B3",X"89",X"82",X"5E",X"5E",X"5E",X"5E",X"82",X"82",X"83",X"89",X"AD",X"56",X"00",X"00",X"00",X"00",X"57",X"AC",X"AD",X"83",X"5E",X"5E",X"58",X"5E",X"82",X"5E",X"83",X"89",X"AD",X"88",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"56",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"81",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"2B",X"81",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"81",X"2B",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"5C",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"88",X"81",X"5D",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",
X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00",X"00"
);  
  
  signal vga_hblank, vga_hsync,
    vga_vblank, vga_vsync : std_logic;  -- Sync. signals

  signal rectangle_h, rectangle_v, rectangle, rectangle_h_B, rectangle_v_B, rectangle_B, rectangle_h_C, rectangle_v_C, rectangle_C, 
    rectangle_h_E, rectangle_v_E, rectangle_E,rectangle_h_E1, rectangle_v_E1, rectangle_E1,rectangle_h_E2, rectangle_v_E2, rectangle_E2,
    rectangle_h_BM, rectangle_v_BM, rectangle_BM, rectangle_h_LV1, rectangle_v_LV1, rectangle_LV1, rectangle_h_LV2, rectangle_LV2,
	 rectangle_h_LV3, rectangle_LV3,rectangle_v_BU, rectangle_h_BU1, rectangle_BU1,rectangle_h_BU2, rectangle_BU2,rectangle_h_BU3, rectangle_BU3,
	 rectangle_h_BU4, rectangle_BU4,rectangle_h_BU5, rectangle_BU5, rectangle_h_BOX, rectangle_v_BOX, rectangle_BOX : std_logic;  -- rectangle area


type ram_type is array(31 downto 0) of
            std_logic_vector(15 downto 0);
  signal RAM : ram_type:=(
	1 =>    "0000000011100000",
	14 =>   "0000000011100000",
	2 =>    "0000000010111000",
	13 =>   "0000000010111000",
	3 =>    "0000000010111000",
	19 =>    "0000000000000000", --BG controller 	
	20 =>    "0000000101111110", --BOX H
	21 =>    "0000000101111110", --BOX V
	22 =>    "0000000111111110", --Bullet# 5
	23 =>    "0000000111101010", --Bullet# 4
	24 =>    "0000000111010110", --Bullet# 3
	25 =>    "0000000111000010", --Bullet# 2
	26 =>    "0000000110101110", --Bullet# 1
	27 =>    "0000000101001010", --Lives 3
	28 =>    "0000000100101100", --Lives 2
	29 =>    "0000000100001110", --Lives 1
	others=>"0000000000000000");
  signal ram_address: unsigned(4 downto 0);


begin
 ram_address <= unsigned(address(4 downto 0));
 
 -- Clock handler
 clock_handler : process(clk50)
   begin
    if rising_edge(clk50) then
      clk <= not clk;
    end if;
  end process clock_handler;
 
 distinguish: process(clk)
  begin
     if rising_edge(clk) then
      if reset_n = '0' then
      	mark <= '0';        
      else
         mark <= not mark;
       end if;
		end if;
	end process distinguish;
 
 -- Memory handler
  Memory_handle: process (clk50)
  begin
    if rising_edge(clk50) then
      if reset_n = '0' then
      	readdata <= (others => '0');        
      else
        if chipselect = '1' then      
            if read = '1' then
              readdata <= RAM(conv_integer(ram_address));
            elsif write = '1' then
              RAM(conv_integer(ram_address)) <= writedata;
            end if;
        end if;
      end if;
    end if;
  end process Memory_handle;

  -- Horizontal and vertical counters
  HCounter2 : process (clk)
  begin
    if rising_edge(clk) then      
      if reset_n = '0' then
        Hcount <= (others => '0');
      elsif EndOfLine = '1' then
        Hcount <= (others => '0');
      else
        Hcount <= Hcount + 1;
      end if;      
    end if;
  end process HCounter2;

  EndOfLine <= '1' when Hcount = HTOTAL - 1 else '0';
  
  VCounter2: process (clk)
  begin
    if rising_edge(clk) then      
      if reset_n = '0' then
        Vcount <= (others => '0');
      elsif EndOfLine = '1' then
        if EndOfField = '1' then
          Vcount <= (others => '0');
        else
          Vcount <= Vcount + 1;
        end if;
      end if;
    end if;
  end process VCounter2;

  EndOfField <= '1' when Vcount = VTOTAL - 1 else '0';

  -- State machines to generate HSYNC, VSYNC, HBLANK, and VBLANK

  HSyncGen : process (clk)
  begin
    if rising_edge(clk) then     
      if reset_n = '0' or EndOfLine = '1' then
        vga_hsync <= '1';
      elsif Hcount = HSYNC - 1 then
        vga_hsync <= '0';
      end if;
    end if;
  end process HSyncGen;
  
  HBlankGen : process (clk)
  begin
    if rising_edge(clk) then
      if reset_n = '0' then
        vga_hblank <= '1';
      elsif Hcount = HSYNC + HBACK_PORCH then
        vga_hblank <= '0';
      elsif Hcount = HSYNC + HBACK_PORCH + HACTIVE then
        vga_hblank <= '1';
      end if;      
    end if;
  end process HBlankGen;

  VSyncGen : process (clk)
  begin
    if rising_edge(clk) then
      if reset_n = '0' then
        vga_vsync <= '1';
      elsif EndOfLine ='1' then
        if EndOfField = '1' then
          vga_vsync <= '1';
        elsif Vcount = VSYNC - 1 then
          vga_vsync <= '0';
        end if;
      end if;      
    end if;
  end process VSyncGen;

  VBlankGen : process (clk)
  begin
    if rising_edge(clk) then    
      if reset_n = '0' then
        vga_vblank <= '1';
      elsif EndOfLine = '1' then
        if Vcount = VSYNC + VBACK_PORCH - 1 then
          vga_vblank <= '0';
        elsif Vcount = VSYNC + VBACK_PORCH + VACTIVE - 1 then
          vga_vblank <= '1';
        end if;
      end if;
    end if;
  end process VBlankGen;

  -- Rectangle generator Boss
Boss_V : V_control port map (clk, Vcount, PATTERN_V, CONV_INTEGER(RAM(15)), Vcounter, rectangle_v, reset_n, EndOfLine);
Boss_H : H_control port map (clk, Hcount, PATTERN_H, CONV_INTEGER(RAM(0)), Hcounter, rectangle_h);

  -- Rectangle generator Bullet
Bullet_V : V_control port map (clk, Vcount, PATTERN_V_B, CONV_INTEGER(RAM(14)), Vcounter_B, rectangle_v_B, reset_n, EndOfLine);
Bullet_H : H_control port map (clk, Hcount, PATTERN_H_B, CONV_INTEGER(RAM(1)), Hcounter_B, rectangle_h_B);

  -- Rectangle generator Student
Student_V : V_control port map (clk, Vcount, PATTERN_V_C, CONV_INTEGER(RAM(13)), Vcounter_C, rectangle_v_C, reset_n, EndOfLine);
Student_H : H_control port map (clk, Hcount, PATTERN_H_C, CONV_INTEGER(RAM(2)), Hcounter_C, rectangle_h_C);

  -- Rectangle generator Enemy0
Enemy0_V : V_control port map (clk, Vcount, PATTERN_V_E, CONV_INTEGER(RAM(12)), Vcounter_E, rectangle_v_E, reset_n, EndOfLine);
Enemy0_H : H_control port map (clk, Hcount, PATTERN_H_E, CONV_INTEGER(RAM(3)), Hcounter_E, rectangle_h_E);

  -- Rectangle generator Enemy1
Enemy1_V : V_control port map (clk, Vcount, PATTERN_V_E, CONV_INTEGER(RAM(11)), Vcounter_E1, rectangle_v_E1, reset_n, EndOfLine);
Enemy1_H : H_control port map (clk, Hcount, PATTERN_H_E, CONV_INTEGER(RAM(4)), Hcounter_E1, rectangle_h_E1);

  -- Rectangle generator Enemy2
Enemy2_V : V_control port map (clk, Vcount, PATTERN_V_E, CONV_INTEGER(RAM(10)), Vcounter_E2, rectangle_v_E2, reset_n, EndOfLine);
Enemy2_H : H_control port map (clk, Hcount, PATTERN_H_E, CONV_INTEGER(RAM(5)), Hcounter_E2, rectangle_h_E2);

  -- Rectangle generator Bomb
Bomb_v : V_control port map (clk, Vcount, PATTERN_V_E, CONV_INTEGER(RAM(8)), Vcounter_BM, rectangle_v_BM, reset_n, EndOfLine);
Bomb_H : H_control port map (clk, Hcount, PATTERN_H_E, CONV_INTEGER(RAM(7)), Hcounter_BM, rectangle_h_BM);

 -- Rectangle generator Lives
LV1_v : V_control port map (clk, Vcount, 30, 70, Vcounter_LV1, rectangle_v_LV1, reset_n, EndOfLine);
LV1_H : H_control port map (clk, Hcount, 30, CONV_INTEGER(RAM(29)), Hcounter_LV1, rectangle_h_LV1);
LV2_H : H_control port map (clk, Hcount, 30, CONV_INTEGER(RAM(28)), Hcounter_LV2, rectangle_h_LV2);
LV3_H : H_control port map (clk, Hcount, 30, CONV_INTEGER(RAM(27)), Hcounter_LV3, rectangle_h_LV3);

BUN_v : V_control port map (clk, Vcount, 46, 65, Vcounter_BU, rectangle_v_BU, reset_n, EndOfLine);
BUN1_H : H_control port map (clk, Hcount, 20, CONV_INTEGER(RAM(26)), Hcounter_BU1, rectangle_h_BU1);
BUN2_H : H_control port map (clk, Hcount, 20, CONV_INTEGER(RAM(25)), Hcounter_BU2, rectangle_h_BU2);
BUN3_H : H_control port map (clk, Hcount, 20, CONV_INTEGER(RAM(24)), Hcounter_BU3, rectangle_h_BU3);
BUN4_H : H_control port map (clk, Hcount, 20, CONV_INTEGER(RAM(23)), Hcounter_BU4, rectangle_h_BU4);
BUN5_H : H_control port map (clk, Hcount, 20, CONV_INTEGER(RAM(22)), Hcounter_BU5, rectangle_h_BU5);

  -- Rectangle generator Box
BOX_v : V_control port map (clk, Vcount, 46, CONV_INTEGER(RAM(21)), Vcounter_BOX, rectangle_v_BOX, reset_n, EndOfLine);
BOX_H : H_control port map (clk, Hcount, 60, CONV_INTEGER(RAM(20)), Hcounter_BOX, rectangle_h_BOX);

rectangle <= rectangle_h and rectangle_v;
rectangle_B <= rectangle_h_B and rectangle_v_B;-- and not rectangle;
rectangle_C <= rectangle_h_C and rectangle_v_C;-- and not rectangle and not rectangle_B;
rectangle_BM <= rectangle_h_BM and rectangle_v_BM;-- and not rectangle and not rectangle_B and not rectangle_C;

rectangle_E <= rectangle_h_E and rectangle_v_E;
rectangle_E1 <= rectangle_h_E1 and rectangle_v_E1;-- and not rectangle_E;
rectangle_E2 <= rectangle_h_E2 and rectangle_v_E2;-- and not rectangle_E and not rectangle_E1;

rectangle_LV1 <= rectangle_h_LV1 and rectangle_v_LV1;
rectangle_LV2 <= rectangle_h_LV2 and rectangle_v_LV1;
rectangle_LV3 <= rectangle_h_LV3 and rectangle_v_LV1;

rectangle_BU1 <= rectangle_h_BU1 and rectangle_v_BU;
rectangle_BU2 <= rectangle_h_BU2 and rectangle_v_BU;
rectangle_BU3 <= rectangle_h_BU3 and rectangle_v_BU;
rectangle_BU4 <= rectangle_h_BU4 and rectangle_v_BU;
rectangle_BU5 <= rectangle_h_BU5 and rectangle_v_BU;

rectangle_BOX <= rectangle_h_BOX and rectangle_v_BOX;

process (clk)
variable index1 : integer :=0;
variable index8 : integer :=0;
begin
if clk'event and clk = '1' then
	index1 := Vcounter*PATTERN_H+Hcounter;
	if CONV_INTEGER(ram(30)) = 2 then
		cmpindex1 <= CONV_INTEGER(pattern3(index1));
	elsif CONV_INTEGER(ram(30)) = 1 then
		cmpindex1 <= CONV_INTEGER(pattern2(index1));
	else
		cmpindex1 <= CONV_INTEGER(pattern(index1));
	end if;
	index8 := Vcounter_BM*PATTERN_H_E+Hcounter_BM;
	cmpindex8 <=CONV_INTEGER(bomb(index8));
end if;
end process;

process (clk)
variable indexBU1 : integer :=0;
variable indexBU2 : integer :=0;
variable indexBU3 : integer :=0;
variable indexBU4 : integer :=0;
variable indexBU5 : integer :=0;
begin
if clk'event and clk = '1' then
	indexBU1 := Vcounter_BU*20+Hcounter_BU1;
	cmpindexBU1 <=CONV_INTEGER(BUN(indexBU1));
	indexBU2 := Vcounter_BU*20+Hcounter_BU2;
	cmpindexBU2 <=CONV_INTEGER(BUN(indexBU2));
	indexBU3 := Vcounter_BU*20+Hcounter_BU3;
	cmpindexBU3 <=CONV_INTEGER(BUN(indexBU3));
	indexBU4 := Vcounter_BU*20+Hcounter_BU4;
	cmpindexBU4 <=CONV_INTEGER(BUN(indexBU4));
	indexBU5 := Vcounter_BU*20+Hcounter_BU5;
	cmpindexBU5 <=CONV_INTEGER(BUN(indexBU5));
end if;
end process;

RGB3 : process (clk)
variable colorindex : std_logic_vector(23 downto 0);
begin
if clk'event and clk = '1' then
  if rectangle = '1' and not (cmpindex1=0) then
			colorindex := colormap(cmpindex1);
  			LEVEL_3_R(9 downto 2) <=colorindex(23 downto 16);
  			LEVEL_3_G(9 downto 2) <=colorindex(15 downto 8);
  			LEVEL_3_B(9 downto 2) <=colorindex(7 downto 0);
			level_3 <= '1';
  elsif rectangle_BM ='1' and not (cmpindex8=0)then
			colorindex := colormap(cmpindex8);
  			LEVEL_3_R(9 downto 2)<=colorindex(23 downto 16);
  			LEVEL_3_G(9 downto 2)<=colorindex(15 downto 8);
  			LEVEL_3_B(9 downto 2)<=colorindex(7 downto 0);
			level_3 <= '1';
  elsif rectangle_BU1 = '1' and not (cmpindexBU1=0) then
		colorindex := colormap(cmpindexBU1);
  		LEVEL_3_R(9 downto 2)<=colorindex(23 downto 16);
  		LEVEL_3_G(9 downto 2)<=colorindex(15 downto 8);
  		LEVEL_3_B(9 downto 2)<=colorindex(7 downto 0);
		level_3 <= '1';
	elsif rectangle_BU2 = '1' and not (cmpindexBU2=0) then
		colorindex := colormap(cmpindexBU2);
  		LEVEL_3_R(9 downto 2)<=colorindex(23 downto 16);
  		LEVEL_3_G(9 downto 2)<=colorindex(15 downto 8);
  		LEVEL_3_B(9 downto 2)<=colorindex(7 downto 0);
		level_3 <= '1';
	elsif rectangle_BU3 = '1' and not (cmpindexBU3=0) then
		colorindex := colormap(cmpindexBU3);
  		LEVEL_3_R(9 downto 2)<=colorindex(23 downto 16);
  		LEVEL_3_G(9 downto 2)<=colorindex(15 downto 8);
  		LEVEL_3_B(9 downto 2)<=colorindex(7 downto 0);
		level_3 <= '1';	
	elsif rectangle_BU4 = '1' and not (cmpindexBU4=0) then
		colorindex := colormap(cmpindexBU4);
  		LEVEL_3_R(9 downto 2)<=colorindex(23 downto 16);
  		LEVEL_3_G(9 downto 2)<=colorindex(15 downto 8);
  		LEVEL_3_B(9 downto 2)<=colorindex(7 downto 0);
		level_3 <= '1';
	elsif rectangle_BU5 ='1' and not (cmpindexBU5=0) then
		colorindex := colormap(cmpindexBU5);
  		LEVEL_3_R(9 downto 2)<=colorindex(23 downto 16);
  		LEVEL_3_G(9 downto 2)<=colorindex(15 downto 8);
  		LEVEL_3_B(9 downto 2)<=colorindex(7 downto 0);
		level_3 <= '1';			
  else
		level_3 <= '0';
  end if;
end if; 
end process RGB3;

process (clk)
variable index2 : integer :=0;
variable index3 : integer :=0;
begin
if clk'event and clk = '1' then
	index2 := Vcounter_B*PATTERN_H_B+Hcounter_B;
	cmpindex2 <=CONV_INTEGER(B1(index2));
	index3 := Vcounter_C*PATTERN_H_C+Hcounter_C;
	if CONV_INTEGER(ram(31))=0 then
		cmpindex3 <= CONV_INTEGER(C1(index3));
	else
		cmpindex3 <= CONV_INTEGER(C2(index3));
	end if;
end if;
end process;

process (clk)
variable index4 : integer :=0;
variable index5 : integer :=0;
variable index6 : integer :=0;
variable indexLV1 : integer :=0;
variable indexLV2 : integer :=0;
variable indexLV3 : integer :=0;
variable indexBOX : integer :=0;
begin
if clk'event and clk = '1' then
	index4 := Vcounter_E*PATTERN_H_E+Hcounter_E;
	cmpindex4 <=CONV_INTEGER(E1(index4));
	index5 := Vcounter_E1*PATTERN_H_E+Hcounter_E1;
	cmpindex5 <=CONV_INTEGER(E1(index5));
	index6 := Vcounter_E2*PATTERN_H_E+Hcounter_E2;
	cmpindex6 <=CONV_INTEGER(E1(index6));
	indexLV1 := Vcounter_LV1*30+Hcounter_LV1;
	cmpindexLV1 <=CONV_INTEGER(lives(indexLV1));
	indexLV2 := Vcounter_LV1*30+Hcounter_LV2;
	cmpindexLV2 <=CONV_INTEGER(lives(indexLV2));
	indexLV3 := Vcounter_LV1*30+Hcounter_LV3;
	cmpindexLV3 <=CONV_INTEGER(lives(indexLV3));
	indexBOX := Vcounter_BOX*60+Hcounter_BOX;
	cmpindexBOX <=CONV_INTEGER(BOX(indexBOX));	
end if;
end process;

RGB2 : process (clk) 
variable colorindex : std_logic_vector(23 downto 0);
begin
if clk'event and clk = '1' then
  if rectangle_B = '1' and (not (cmpindex2=0))then
			colorindex := colormap(cmpindex2);
  			LEVEL_2_R(9 downto 2)<=colorindex(23 downto 16);
  			LEVEL_2_G(9 downto 2)<=colorindex(15 downto 8);
  			LEVEL_2_B(9 downto 2)<=colorindex(7 downto 0);
			level_2 <= '1';			
  elsif rectangle_C ='1' and (not (cmpindex3=0))then
			colorindex := colormap(cmpindex3);
  			LEVEL_2_R(9 downto 2)<=colorindex(23 downto 16);
  			LEVEL_2_G(9 downto 2)<=colorindex(15 downto 8);
  			LEVEL_2_B(9 downto 2)<=colorindex(7 downto 0);
			level_2 <= '1';
  elsif rectangle_LV1 = '1' and not (cmpindexLV1=0) then
		colorindex := colormap(cmpindexLV1);
  		LEVEL_2_R(9 downto 2)<=colorindex(23 downto 16);
  		LEVEL_2_G(9 downto 2)<=colorindex(15 downto 8);
  		LEVEL_2_B(9 downto 2)<=colorindex(7 downto 0);
		level_2 <= '1';
	elsif rectangle_LV2 = '1' and not (cmpindexLV2=0) then
		colorindex := colormap(cmpindexLV2);
  		LEVEL_2_R(9 downto 2)<=colorindex(23 downto 16);
  		LEVEL_2_G(9 downto 2)<=colorindex(15 downto 8);
  		LEVEL_2_B(9 downto 2)<=colorindex(7 downto 0);
		level_2 <= '1';
	elsif rectangle_LV3 = '1' and not (cmpindexLV3=0) then
		colorindex := colormap(cmpindexLV3);
  		LEVEL_2_R(9 downto 2)<=colorindex(23 downto 16);
  		LEVEL_2_G(9 downto 2)<=colorindex(15 downto 8);
  		LEVEL_2_B(9 downto 2)<=colorindex(7 downto 0);
		level_2 <= '1';			
  else
      level_2 <= '0';
  end if;
end if; 
end process RGB2;

RGB1 : process (clk)
variable colorindex : std_logic_vector(23 downto 0);
begin
if clk'event and clk = '1' then	
	if rectangle_E = '1' and not (cmpindex4=0) then
		colorindex := colormap(cmpindex4);
  		LEVEL_1_R(9 downto 2)<=colorindex(23 downto 16);
  		LEVEL_1_G(9 downto 2)<=colorindex(15 downto 8);
  		LEVEL_1_B(9 downto 2)<=colorindex(7 downto 0);
		level_1 <= '1';
	elsif rectangle_E1 ='1' and not (cmpindex5=0) then
		colorindex := colormap(cmpindex5);
  		LEVEL_1_R(9 downto 2)<=colorindex(23 downto 16);
  		LEVEL_1_G(9 downto 2)<=colorindex(15 downto 8);
  		LEVEL_1_B(9 downto 2)<=colorindex(7 downto 0); 
		level_1 <= '1';
	elsif rectangle_E2 ='1' and not (cmpindex6=0)then
		colorindex := colormap(cmpindex6);
  		LEVEL_1_R(9 downto 2)<=colorindex(23 downto 16);
  		LEVEL_1_G(9 downto 2)<=colorindex(15 downto 8);
  		LEVEL_1_B(9 downto 2)<=colorindex(7 downto 0);
		level_1 <= '1';
	elsif rectangle_BOX ='1' and not (cmpindexBOX=0)then
		colorindex := colormap(cmpindexBOX);
  		LEVEL_1_R(9 downto 2)<=colorindex(23 downto 16);
  		LEVEL_1_G(9 downto 2)<=colorindex(15 downto 8);
  		LEVEL_1_B(9 downto 2)<=colorindex(7 downto 0);
		level_1 <= '1';
	else
      level_1 <= '0';
	end if;
end if;
end process RGB1;


RGB0 : process (clk)
variable cmpindexBG : integer :=0;
variable colorindex : std_logic_vector(23 downto 0);
begin
if clk'event and clk = '1' then
	if mark = '0' then
		cmpindexBG := conv_integer(sram_read(15 downto 8));
	elsif mark ='1' then
		cmpindexBG := conv_integer(sram_read(7 downto 0));
	end if;
		colorindex := colormap(cmpindexBG);
		level_0_R(9 downto 2) <= colorindex(23 downto 16);
		level_0_G(9 downto 2) <= colorindex(15 downto 8);
		level_0_B(9 downto 2) <= colorindex(7 downto 0);
end if;
end process RGB0;



  -- Registered video signals going to the video DAC

  VideoOut: process (reset_n, clk)
  begin
    if reset_n = '0' then
      VGA_R <= "0000000000";
      VGA_G <= "0000000000";
      VGA_B <= "0000000000";
    elsif clk'event and clk = '1' then
		if level_3 = '1' then
        	VGA_R <= LEVEL_3_R;
       	VGA_G <= LEVEL_3_G;
       	VGA_B <= LEVEL_3_B;	 
		elsif level_2 = '1' then
        	VGA_R <= LEVEL_2_R;
       	VGA_G <= LEVEL_2_G;
       	VGA_B <= LEVEL_2_B;
      elsif level_1 = '1'then
	    	VGA_R <= LEVEL_1_R;
        	VGA_G <= LEVEL_1_G;
        	VGA_B <= LEVEL_1_B;     
      elsif vga_hblank = '0' and vga_vblank ='0' then
			VGA_R <= LEVEL_0_R;
        	VGA_G <= LEVEL_0_G;
        	VGA_B <= LEVEL_0_B;  
      else
        VGA_R <= "0000000000";
        VGA_G <= "0000000000";
        VGA_B <= "0000000000";    
      end if;
    end if;
  end process VideoOut;

  VGA_CLK <= clk;
  VGA_HS <= not vga_hsync;
  VGA_VS <= not vga_vsync;
  VGA_SYNC <= '0';
  VGA_BLANK <= not (vga_hsync or vga_vsync);
  hcounter_s <= conv_integer(Hcount);
  vcounter_s <= conv_integer(Vcount);

process (clk)
  begin
    if rising_edge(clk) then
      if reset_n = '0' then
      	sram_add <= (others => '0');        
      elsif CONV_INTEGER(RAM(19))=1 and hcounter_s<450+HSYNC+HBACK_PORCH-1 and hcounter_s>150+HSYNC+HBACK_PORCH-1 and vcounter_s<430+VSYNC+VBACK_PORCH-1 and vcounter_s>330+VSYNC+VBACK_PORCH-1 then	
			 sram_add <=Conv_std_logic_vector((hcounter_s - HSYNC - HBACK_PORCH-150)/2+ (vcounter_s-VSYNC-VBACK_PORCH-330)*150+153600 ,18);
		
		elsif CONV_INTEGER(RAM(19))=2 and hcounter_s<350+HSYNC+HBACK_PORCH-1 and hcounter_s>200+HSYNC+HBACK_PORCH-1 and vcounter_s<430+VSYNC+VBACK_PORCH-1 and vcounter_s>330+VSYNC+VBACK_PORCH-1 then	
			 sram_add <=Conv_std_logic_vector((hcounter_s - HSYNC - HBACK_PORCH-200)/2+ (vcounter_s-VSYNC-VBACK_PORCH-330)*75+168600 ,18);
		
		elsif CONV_INTEGER(RAM(19))=3 and hcounter_s<350+HSYNC+HBACK_PORCH-1 and hcounter_s>200+HSYNC+HBACK_PORCH-1 and vcounter_s<430+VSYNC+VBACK_PORCH-1 and vcounter_s>330+VSYNC+VBACK_PORCH-1 then	
			 sram_add <=Conv_std_logic_vector((hcounter_s - HSYNC - HBACK_PORCH-200)/2+ (vcounter_s-VSYNC-VBACK_PORCH-330)*75+176100 ,18);
		
		elsif CONV_INTEGER(RAM(19))=4 and hcounter_s<350+HSYNC+HBACK_PORCH-1 and hcounter_s>200+HSYNC+HBACK_PORCH-1 and vcounter_s<430+VSYNC+VBACK_PORCH-1 and vcounter_s>330+VSYNC+VBACK_PORCH-1 then	
			 sram_add <=Conv_std_logic_vector((hcounter_s - HSYNC - HBACK_PORCH-200)/2+ (vcounter_s-VSYNC-VBACK_PORCH-330)*75+183600 ,18);
		
		elsif CONV_INTEGER(RAM(19))=0 and hcounter_s<260+HSYNC+HBACK_PORCH-1 and hcounter_s>200+HSYNC+HBACK_PORCH-1 and vcounter_s<470+VSYNC+VBACK_PORCH-1 and vcounter_s>440+VSYNC+VBACK_PORCH-1 then
			 sram_add <=Conv_std_logic_vector((hcounter_s - HSYNC - HBACK_PORCH-200)/2+ (vcounter_s-VSYNC-VBACK_PORCH-440)*30+193500 ,18);		
		
		elsif CONV_INTEGER(RAM(19))=0 and hcounter_s<276+HSYNC+HBACK_PORCH-1 and hcounter_s>260+HSYNC+HBACK_PORCH-1 and vcounter_s<470+VSYNC+VBACK_PORCH-1 and vcounter_s>440+VSYNC+VBACK_PORCH-1 then
			 sram_add <=Conv_std_logic_vector((hcounter_s - HSYNC - HBACK_PORCH-260)/2+ (vcounter_s-VSYNC-VBACK_PORCH-440)*8+191100+CONV_INTEGER(RAM(9))*240 ,18);
		
		elsif CONV_INTEGER(RAM(19))=0 and hcounter_s<292+HSYNC+HBACK_PORCH-1 and hcounter_s>276+HSYNC+HBACK_PORCH-1 and vcounter_s<470+VSYNC+VBACK_PORCH-1 and vcounter_s>440+VSYNC+VBACK_PORCH-1 then
			 sram_add <=Conv_std_logic_vector((hcounter_s - HSYNC - HBACK_PORCH-276)/2+ (vcounter_s-VSYNC-VBACK_PORCH-440)*8+191100+CONV_INTEGER(RAM(16))*240 ,18);
		
		elsif CONV_INTEGER(RAM(19))=0 and hcounter_s<308+HSYNC+HBACK_PORCH-1 and hcounter_s>292+HSYNC+HBACK_PORCH-1 and vcounter_s<470+VSYNC+VBACK_PORCH-1 and vcounter_s>440+VSYNC+VBACK_PORCH-1 then
			 sram_add <=Conv_std_logic_vector((hcounter_s - HSYNC - HBACK_PORCH-292)/2+ (vcounter_s-VSYNC-VBACK_PORCH-440)*8+191100+CONV_INTEGER(RAM(17))*240 ,18);		
		
		elsif CONV_INTEGER(RAM(19))=0 and hcounter_s<324+HSYNC+HBACK_PORCH-1 and hcounter_s>308+HSYNC+HBACK_PORCH-1 and vcounter_s<470+VSYNC+VBACK_PORCH-1 and vcounter_s>440+VSYNC+VBACK_PORCH-1 then
			 sram_add <=Conv_std_logic_vector((hcounter_s - HSYNC - HBACK_PORCH-308)/2+ (vcounter_s-VSYNC-VBACK_PORCH-440)*8+191100+CONV_INTEGER(RAM(18))*240 ,18);		
		
		else	 
			sram_add <=Conv_std_logic_vector((hcounter_s - HSYNC - HBACK_PORCH)/2+ (vcounter_s-VSYNC-VBACK_PORCH-1)*320 ,18);
      end if;
    end if;
  end process;

end rtl;
